Skip to content

Docker stable release doesn't work #5134

Description

@officiallor

Describe the bug
Tried installing the stable version but the script doesn't work. It requires a Dockerfile when in the script it just downloads the docker-compose.yml. With develop version it has some python stacktrace on machine startup

Activity

  1. grimsius commented on Jan 25, 2026

    @grimsius

    Perhaps this will help someone, or a developer will take note. There is a known issue where the application Hiddify-Manager fails to launch in Docker. I slightly modified the original docker-compose.yml, and now it looks like this:

    services:
      hiddify:
        image: ghcr.io/hiddify/hiddify-manager:latest
        ports:
          - "80:80"
          - "443:443"
        privileged: true
        cap_add:
          - NET_ADMIN
        volumes:
          - ./docker-data/:/hiddify-data/
        env_file:
          - .env
        environment:
          REDIS_URI_MAIN: 'redis://:${REDIS_PASSWORD}@redis:6379/0'
          REDIS_URI_SSH: 'redis://:${REDIS_PASSWORD}@redis:6379/1'
          SQLALCHEMY_DATABASE_URI: 'mysql+mysqldb://hiddifypanel:${MYSQL_PASSWORD}@mariadb/hiddifypanel?charset=utf8mb4'
        depends_on:
          - mariadb
          - redis
    
      mariadb:
        image: mariadb:latest
        container_name: mariadb_container
        restart: always
        env_file:
          - .env
        environment:
          MARIADB_RANDOM_ROOT_PASSWORD: 1
          MYSQL_DATABASE: hiddifypanel
          MYSQL_USER: hiddifypanel
          MYSQL_PASSWORD: ${MYSQL_PASSWORD}
        volumes:
          - ./docker-data/mariadb_data:/var/lib/mysql
    
      redis:
        image: redis:latest
        container_name: redis_container
        restart: always
        env_file:
          - .env
        command: redis-server --requirepass ${REDIS_PASSWORD}
        volumes:
          - ./docker-data/redis_data:/data

    Required changes:

    1. The file docker.env must be renamed to .env

    The .env file MUST contain two lines with approximately the following content:

    REDIS_PASSWORD=strong_redis_password
    MYSQL_PASSWORD=strong_mysql_password
    1. If there was already a failed launch attempt, the directory /docker-data/ in the parent /hiddify-manager/ must be deleted:
    sudo rm -rf ~/hiddify-manager/docker-data/

    Launch from the /hiddify-manager/ directory where it is located docker-compose.yml

    docker compose up -d && docker compose logs -f

    With this docker-compose.yml, it launches, but inside the container, two applications:

    • hiddify-singbox --> do not work.
    • hiddify-ss-faketls --> do not work.
    ⚠️Full container startup log:
    admin@ubuntu-24:/hiddify-manager$ docker compose up -d && docker compose logs -f
    [+] up 4/4
     ✔ Network hiddify-manager_default     Created                                                                                                                                                      0.0s
     ✔ Container mariadb_container         Created                                                                                                                                                      0.1s
     ✔ Container redis_container           Created                                                                                                                                                      0.1s
     ✔ Container hiddify-manager-hiddify-1 Created                                                                                                                                                      0.0s
    redis_container  | Starting Redis Server
    redis_container  | 1:C 24 Jan 2026 18:59:35.980 # WARNING Memory overcommit must be enabled! Without it, a background save or replication may fail under low memory condition. Being disabled, it can also cause failures without low memory condition, see https://github.com/jemalloc/jemalloc/issues/1328. To fix this issue add 'vm.overcommit_memory = 1' to /etc/sysctl.conf and then reboot or run the command 'sysctl vm.overcommit_memory=1' for this to take effect.
    redis_container  | 1:C 24 Jan 2026 18:59:35.980 * oO0OoO0OoO0Oo Redis is starting oO0OoO0OoO0Oo
    redis_container  | 1:C 24 Jan 2026 18:59:35.980 * Redis version=8.4.0, bits=64, commit=00000000, modified=1, pid=1, just started
    redis_container  | 1:C 24 Jan 2026 18:59:35.980 * Configuration loaded
    redis_container  | 1:M 24 Jan 2026 18:59:35.980 * Increased maximum number of open files to 10032 (it was originally set to 1024).
    redis_container  | 1:M 24 Jan 2026 18:59:35.980 * monotonic clock: POSIX clock_gettime
    redis_container  | 1:M 24 Jan 2026 18:59:35.982 * Running mode=standalone, port=6379.
    redis_container  | 1:M 24 Jan 2026 18:59:35.986 * <bf> RedisBloom version 8.4.0 (Git=unknown)
    redis_container  | 1:M 24 Jan 2026 18:59:35.986 * <bf> Registering configuration options: [
    redis_container  | 1:M 24 Jan 2026 18:59:35.986 * <bf>  { bf-error-rate       :      0.01 }
    redis_container  | 1:M 24 Jan 2026 18:59:35.986 * <bf>  { bf-initial-size     :       100 }
    redis_container  | 1:M 24 Jan 2026 18:59:35.986 * <bf>  { bf-expansion-factor :         2 }
    redis_container  | 1:M 24 Jan 2026 18:59:35.986 * <bf>  { cf-bucket-size      :         2 }
    redis_container  | 1:M 24 Jan 2026 18:59:35.986 * <bf>  { cf-initial-size     :      1024 }
    redis_container  | 1:M 24 Jan 2026 18:59:35.986 * <bf>  { cf-max-iterations   :        20 }
    redis_container  | 1:M 24 Jan 2026 18:59:35.986 * <bf>  { cf-expansion-factor :         1 }
    redis_container  | 1:M 24 Jan 2026 18:59:35.986 * <bf>  { cf-max-expansions   :        32 }
    redis_container  | 1:M 24 Jan 2026 18:59:35.986 * <bf> ]
    redis_container  | 1:M 24 Jan 2026 18:59:35.987 * Module 'bf' loaded from /usr/local/lib/redis/modules//redisbloom.so
    redis_container  | 1:M 24 Jan 2026 18:59:36.013 * <search> Redis version found by RedisSearch : 8.4.0 - oss
    redis_container  | 1:M 24 Jan 2026 18:59:36.013 * <search> RediSearch version 8.4.2 (Git=9e2b676)
    redis_container  | 1:M 24 Jan 2026 18:59:36.014 * <search> Low level api version 1 initialized successfully
    redis_container  | 1:M 24 Jan 2026 18:59:36.016 * <search> gc: ON, prefix min length: 2, min word length to stem: 4, prefix max expansions: 200, query timeout (ms): 500, timeout policy: return, oom policy: return, cursor read size: 1000, cursor max idle (ms): 300000, max doctable size: 1000000, max number of search results:  1000000, default scorer: BM25STD,
    redis_container  | 1:M 24 Jan 2026 18:59:36.019 * <search> Initialized thread pools!
    redis_container  | 1:M 24 Jan 2026 18:59:36.019 * <search> Disabled workers threadpool of size 0
    redis_container  | 1:M 24 Jan 2026 18:59:36.021 * <search> Subscribe to config changes
    redis_container  | 1:M 24 Jan 2026 18:59:36.021 * <search> Subscribe to cluster slot migration events
    redis_container  | 1:M 24 Jan 2026 18:59:36.021 * <search> Enabled role change notification
    redis_container  | 1:M 24 Jan 2026 18:59:36.021 * <search> Cluster configuration: AUTO partitions, type: 0, coordinator timeout: 0ms
    redis_container  | 1:M 24 Jan 2026 18:59:36.021 * <search> Register write commands
    redis_container  | 1:M 24 Jan 2026 18:59:36.021 * Module 'search' loaded from /usr/local/lib/redis/modules//redisearch.so
    redis_container  | 1:M 24 Jan 2026 18:59:36.025 * <timeseries> RedisTimeSeries version 80400, git_sha=3520a1568ad69076d60885c70711fbdc9b448749
    redis_container  | 1:M 24 Jan 2026 18:59:36.025 * <timeseries> Redis version found by RedisTimeSeries : 8.4.0 - oss
    redis_container  | 1:M 24 Jan 2026 18:59:36.025 * <timeseries> Registering configuration options: [
    redis_container  | 1:M 24 Jan 2026 18:59:36.025 * <timeseries>  { ts-compaction-policy   :              }
    redis_container  | 1:M 24 Jan 2026 18:59:36.025 * <timeseries>  { ts-num-threads         :            3 }
    redis_container  | 1:M 24 Jan 2026 18:59:36.025 * <timeseries>  { ts-retention-policy    :            0 }
    redis_container  | 1:M 24 Jan 2026 18:59:36.025 * <timeseries>  { ts-duplicate-policy    :        block }
    redis_container  | 1:M 24 Jan 2026 18:59:36.025 * <timeseries>  { ts-chunk-size-bytes    :         4096 }
    redis_container  | 1:M 24 Jan 2026 18:59:36.025 * <timeseries>  { ts-encoding            :   compressed }
    redis_container  | 1:M 24 Jan 2026 18:59:36.025 * <timeseries>  { ts-ignore-max-time-diff:            0 }
    redis_container  | 1:M 24 Jan 2026 18:59:36.025 * <timeseries>  { ts-ignore-max-val-diff :     0.000000 }
    redis_container  | 1:M 24 Jan 2026 18:59:36.025 * <timeseries> ]
    redis_container  | 1:M 24 Jan 2026 18:59:36.025 * <timeseries> Detected redis oss
    redis_container  | 1:M 24 Jan 2026 18:59:36.026 * <timeseries> Subscribe to ASM events
    redis_container  | 1:M 24 Jan 2026 18:59:36.026 * <timeseries> Enabled diskless replication
    redis_container  | 1:M 24 Jan 2026 18:59:36.026 * Module 'timeseries' loaded from /usr/local/lib/redis/modules//redistimeseries.so
    redis_container  | 1:M 24 Jan 2026 18:59:36.038 * <ReJSON> Created new data type 'ReJSON-RL'
    redis_container  | 1:M 24 Jan 2026 18:59:36.038 * <ReJSON> version: 80400 git sha: unknown branch: unknown
    redis_container  | 1:M 24 Jan 2026 18:59:36.039 * <ReJSON> Exported RedisJSON_V1 API
    redis_container  | 1:M 24 Jan 2026 18:59:36.039 * <ReJSON> Exported RedisJSON_V2 API
    redis_container  | 1:M 24 Jan 2026 18:59:36.039 * <ReJSON> Exported RedisJSON_V3 API
    redis_container  | 1:M 24 Jan 2026 18:59:36.039 * <ReJSON> Exported RedisJSON_V4 API
    redis_container  | 1:M 24 Jan 2026 18:59:36.039 * <ReJSON> Exported RedisJSON_V5 API
    redis_container  | 1:M 24 Jan 2026 18:59:36.039 * <ReJSON> Exported RedisJSON_V6 API
    redis_container  | 1:M 24 Jan 2026 18:59:36.040 * <ReJSON> Enabled diskless replication
    redis_container  | 1:M 24 Jan 2026 18:59:36.040 * <ReJSON> Initialized shared string cache, thread safe: true.
    redis_container  | 1:M 24 Jan 2026 18:59:36.040 * Module 'ReJSON' loaded from /usr/local/lib/redis/modules//rejson.so
    redis_container  | 1:M 24 Jan 2026 18:59:36.040 * <search> Acquired RedisJSON_V6 API
    redis_container  | 1:M 24 Jan 2026 18:59:36.040 * Server initialized
    redis_container  | 1:M 24 Jan 2026 18:59:36.040 * Ready to accept connections tcp
    hiddify-1        | System has not been booted with systemd as init system (PID 1). Can't operate.
    hiddify-1        | Failed to connect to bus: Host is down
    hiddify-1        | systemctl returned non-zero exit code. Re install systemctl...
    mariadb_container  | 2026-01-24 18:59:35+00:00 [Note] [Entrypoint]: Entrypoint script for MariaDB Server 1:12.1.2+maria~ubu2404 started.
    mariadb_container  | 2026-01-24 18:59:36+00:00 [Warn] [Entrypoint]: /sys/fs/cgroup///memory.pressure not writable, functionality unavailable to MariaDB
    mariadb_container  | 2026-01-24 18:59:36+00:00 [Note] [Entrypoint]: Switching to dedicated user 'mysql'
    mariadb_container  | 2026-01-24 18:59:36+00:00 [Note] [Entrypoint]: Entrypoint script for MariaDB Server 1:12.1.2+maria~ubu2404 started.
    mariadb_container  | 2026-01-24 18:59:36+00:00 [Note] [Entrypoint]: Initializing database files
    mariadb_container  | 2026-01-24 18:59:36 0 [Warning] mariadbd: io_uring_queue_init() failed with EPERM: sysctl kernel.io_uring_disabled has the value 2, or 1 and the user of the process is not a member of sysctl kernel.io_uring_group. (see man 2 io_uring_setup).
    mariadb_container  | create_uring failed: falling back to libaio
    mariadb_container  | 2026-01-24 18:59:37+00:00 [Note] [Entrypoint]: Database files initialized
    mariadb_container  | 2026-01-24 18:59:37+00:00 [Note] [Entrypoint]: Starting temporary server
    mariadb_container  | 2026-01-24 18:59:37+00:00 [Note] [Entrypoint]: Waiting for server startup
    mariadb_container  | 2026-01-24 18:59:37 0 [Note] Starting MariaDB 12.1.2-MariaDB-ubu2404 source revision 70117463f032d59f8e328335e19b59157d34cf07 server_uid kUUprsMvG67k/MHyLDvX0dlqARI= as process 87
    hiddify-1          | ####0####Please wait...####We are going to install Hiddify...####
    mariadb_container  | 2026-01-24 18:59:37 0 [Note] InnoDB: Compressed tables use zlib 1.3
    mariadb_container  | 2026-01-24 18:59:37 0 [Note] InnoDB: Number of transaction pools: 1
    mariadb_container  | 2026-01-24 18:59:37 0 [Note] InnoDB: Using SSE4.2 crc32 instructions
    mariadb_container  | 2026-01-24 18:59:37 0 [Note] mariadbd: O_TMPFILE is not supported on /tmp (disabling future attempts)
    mariadb_container  | 2026-01-24 18:59:37 0 [Warning] mariadbd: io_uring_queue_init() failed with EPERM: sysctl kernel.io_uring_disabled has the value 2, or 1 and the user of the process is not a member of sysctl kernel.io_uring_group. (see man 2 io_uring_setup).
    mariadb_container  | create_uring failed: falling back to libaio
    mariadb_container  | 2026-01-24 18:59:37 0 [Note] InnoDB: Using Linux native AIO
    mariadb_container  | 2026-01-24 18:59:37 0 [Note] InnoDB: innodb_buffer_pool_size_max=128m, innodb_buffer_pool_size=128m
    mariadb_container  | 2026-01-24 18:59:37 0 [Note] InnoDB: Completed initialization of buffer pool
    mariadb_container  | 2026-01-24 18:59:37 0 [Note] InnoDB: File system buffers for log disabled (block size=512 bytes)
    mariadb_container  | 2026-01-24 18:59:37 0 [Note] InnoDB: End of log at LSN=45759
    mariadb_container  | 2026-01-24 18:59:37 0 [Note] InnoDB: Opened 3 undo tablespaces
    mariadb_container  | 2026-01-24 18:59:37 0 [Note] InnoDB: 128 rollback segments in 3 undo tablespaces are active.
    mariadb_container  | 2026-01-24 18:59:37 0 [Note] InnoDB: Setting file './ibtmp1' size to 12.000MiB. Physically writing the file full; Please wait ...
    mariadb_container  | 2026-01-24 18:59:37 0 [Note] InnoDB: File './ibtmp1' size is now 12.000MiB.
    mariadb_container  | 2026-01-24 18:59:37 0 [Note] InnoDB: log sequence number 45759; transaction id 14
    mariadb_container  | 2026-01-24 18:59:37 0 [Note] Plugin 'FEEDBACK' is disabled.
    mariadb_container  | 2026-01-24 18:59:37 0 [Note] Plugin 'wsrep-provider' is disabled.
    hiddify-1          | ####2####Applying...####Common Tools and Requirements####
    hiddify-1          | ===install.sh common
    hiddify-1          | ERROR:systemctl:Unit systemd-resolved.service not found.
    hiddify-1          | Using Python 3.13.11 environment at: /opt/hiddify-manager/.venv313
    hiddify-1          | net.ipv6.conf.all.disable_ipv6 = 0
    hiddify-1          | net.ipv6.conf.default.disable_ipv6 = 0
    hiddify-1          | net.ipv6.conf.lo.disable_ipv6 = 0
    hiddify-1          | mv: cannot stat '/etc/cron.d/hiddify_daily_memory_release': No such file or directory
    hiddify-1          |  * Reloading configuration files for periodic command scheduler cron
    hiddify-1          |    ...done.
    mariadb_container  | 2026-01-24 18:59:41 0 [Note] mariadbd: Event Scheduler: Loaded 0 events
    mariadb_container  | 2026-01-24 18:59:41 0 [Note] Replication not automatically started: --skip-slave-start was specified
    mariadb_container  | 2026-01-24 18:59:41 0 [Note] mariadbd: ready for connections.
    mariadb_container  | Version: '12.1.2-MariaDB-ubu2404'  socket: '/run/mysqld/mysqld.sock'  port: 0  mariadb.org binary distribution
    mariadb_container  | 2026-01-24 18:59:41+00:00 [Note] [Entrypoint]: Temporary server started.
    mariadb_container  | 2026-01-24 18:59:42+00:00 [Note] [Entrypoint]: GENERATED ROOT PASSWORD: S_$4]d@&UgTq~txaFHN+qiq=n<{E`#7@
    mariadb_container  | 2026-01-24 18:59:42+00:00 [Note] [Entrypoint]: Creating database hiddifypanel
    mariadb_container  | 2026-01-24 18:59:42+00:00 [Note] [Entrypoint]: Creating user hiddifypanel
    mariadb_container  | 2026-01-24 18:59:42+00:00 [Note] [Entrypoint]: Giving user hiddifypanel access to schema hiddifypanel
    mariadb_container  | 2026-01-24 18:59:42+00:00 [Note] [Entrypoint]: Securing system users (equivalent to running mysql_secure_installation)
    mariadb_container  |
    mariadb_container  | 2026-01-24 18:59:42+00:00 [Note] [Entrypoint]: Stopping temporary server
    mariadb_container  | 2026-01-24 18:59:42 0 [Note] mariadbd (initiated by: unknown): Normal shutdown
    mariadb_container  | 2026-01-24 18:59:42 0 [Note] InnoDB: FTS optimize thread exiting.
    mariadb_container  | 2026-01-24 18:59:42 0 [Note] InnoDB: Starting shutdown...
    mariadb_container  | 2026-01-24 18:59:42 0 [Note] InnoDB: Dumping buffer pool(s) to /var/lib/mysql/ib_buffer_pool
    mariadb_container  | 2026-01-24 18:59:42 0 [Note] InnoDB: Buffer pool(s) dump completed at 260124 18:59:42
    mariadb_container  | 2026-01-24 18:59:42 0 [Note] InnoDB: Removed temporary tablespace data file: "./ibtmp1"
    mariadb_container  | 2026-01-24 18:59:42 0 [Note] InnoDB: Shutdown completed; log sequence number 46116; transaction id 15
    mariadb_container  | 2026-01-24 18:59:42 0 [Note] mariadbd: Shutdown complete
    mariadb_container  | 2026-01-24 18:59:42+00:00 [Note] [Entrypoint]: Temporary server stopped
    mariadb_container  |
    mariadb_container  | 2026-01-24 18:59:42+00:00 [Note] [Entrypoint]: MariaDB init process done. Ready for start up.
    mariadb_container  |
    mariadb_container  | 2026-01-24 18:59:42 0 [Note] Starting MariaDB 12.1.2-MariaDB-ubu2404 source revision 70117463f032d59f8e328335e19b59157d34cf07 server_uid kUUprsMvG67k/MHyLDvX0dlqARI= as process 1
    mariadb_container  | 2026-01-24 18:59:42 0 [Note] InnoDB: Compressed tables use zlib 1.3
    mariadb_container  | 2026-01-24 18:59:42 0 [Note] InnoDB: Number of transaction pools: 1
    mariadb_container  | 2026-01-24 18:59:42 0 [Note] InnoDB: Using SSE4.2 crc32 instructions
    mariadb_container  | 2026-01-24 18:59:42 0 [Note] mariadbd: O_TMPFILE is not supported on /tmp (disabling future attempts)
    mariadb_container  | 2026-01-24 18:59:42 0 [Warning] mariadbd: io_uring_queue_init() failed with EPERM: sysctl kernel.io_uring_disabled has the value 2, or 1 and the user of the process is not a member of sysctl kernel.io_uring_group. (see man 2 io_uring_setup).
    mariadb_container  | create_uring failed: falling back to libaio
    mariadb_container  | 2026-01-24 18:59:42 0 [Note] InnoDB: Using Linux native AIO
    mariadb_container  | 2026-01-24 18:59:42 0 [Note] InnoDB: innodb_buffer_pool_size_max=128m, innodb_buffer_pool_size=128m
    mariadb_container  | 2026-01-24 18:59:42 0 [Note] InnoDB: Completed initialization of buffer pool
    mariadb_container  | 2026-01-24 18:59:42 0 [Note] InnoDB: File system buffers for log disabled (block size=512 bytes)
    mariadb_container  | 2026-01-24 18:59:42 0 [Note] InnoDB: End of log at LSN=46116
    hiddify-1          | ======================hiddify-panel====================================={
    hiddify-1          | ===run.sh hiddify-panel
    mariadb_container  | 2026-01-24 18:59:42 0 [Note] InnoDB: Opened 3 undo tablespaces
    mariadb_container  | 2026-01-24 18:59:42 0 [Note] InnoDB: 128 rollback segments in 3 undo tablespaces are active.
    mariadb_container  | 2026-01-24 18:59:42 0 [Note] InnoDB: Setting file './ibtmp1' size to 12.000MiB. Physically writing the file full; Please wait ...
    mariadb_container  | 2026-01-24 18:59:42 0 [Note] InnoDB: File './ibtmp1' size is now 12.000MiB.
    mariadb_container  | 2026-01-24 18:59:42 0 [Note] InnoDB: log sequence number 46116; transaction id 15
    mariadb_container  | 2026-01-24 18:59:42 0 [Note] InnoDB: Loading buffer pool(s) from /var/lib/mysql/ib_buffer_pool
    mariadb_container  | 2026-01-24 18:59:42 0 [Note] Plugin 'FEEDBACK' is disabled.
    mariadb_container  | 2026-01-24 18:59:42 0 [Note] InnoDB: Buffer pool(s) load completed at 260124 18:59:42
    mariadb_container  | 2026-01-24 18:59:42 0 [Note] Plugin 'wsrep-provider' is disabled.
    mariadb_container  | 2026-01-24 18:59:45 0 [Note] Server socket created on IP: '0.0.0.0', port: '3306'.
    mariadb_container  | 2026-01-24 18:59:45 0 [Note] Server socket created on IP: '::', port: '3306'.
    mariadb_container  | 2026-01-24 18:59:45 0 [Note] mariadbd: Event Scheduler: Loaded 0 events
    mariadb_container  | 2026-01-24 18:59:45 0 [Note] mariadbd: ready for connections.
    mariadb_container  | Version: '12.1.2-MariaDB-ubu2404'  socket: '/run/mysqld/mysqld.sock'  port: 3306  mariadb.org binary distribution
    hiddify-1          | 2026-01-24 18:59:46.963 | WARNING  | hiddifypanel.panel.init_db:current_db_version:759 - db version not found
    hiddify-1          | 2026-01-24 18:59:47.169 | DEBUG    | hiddifypanel.panel.init_db:execute:707 - migrating_db: (MySQLdb.OperationalError) (1091, "Can't DROP INDEX `name`; check that it exists")
    hiddify-1          | [SQL: ALTER TABLE child DROP INDEX `name`;]
    hiddify-1          | (Background on this error at: https://sqlalche.me/e/20/e3q8)
    hiddify-1          | 2026-01-24 18:59:47.170 | DEBUG    | hiddifypanel.panel.init_db:execute:707 - migrating_db: (MySQLdb.OperationalError) (1091, "Can't DROP COLUMN `connected_ips`; check that it exists")
    hiddify-1          | [SQL: ALTER TABLE user_detail DROP COLUMN connected_ips;]
    hiddify-1          | (Background on this error at: https://sqlalche.me/e/20/e3q8)
    hiddify-1          | 2026-01-24 18:59:47.194 | DEBUG    | hiddifypanel.panel.init_db:execute:707 - migrating_db: (MySQLdb.OperationalError) (1091, "Can't DROP INDEX `name`; check that it exists")
    hiddify-1          | [SQL: ALTER TABLE proxy DROP INDEX `name`;]
    hiddify-1          | (Background on this error at: https://sqlalche.me/e/20/e3q8)
    hiddify-1          | 2026-01-24 18:59:47.225 | DEBUG    | hiddifypanel.panel.init_db:execute:707 - migrating_db: (MySQLdb.OperationalError) (1054, "Unknown column 'monthly_usage_limit_GB' in 'user'")
    hiddify-1          | [SQL: ALTER TABLE user RENAME COLUMN monthly_usage_limit_GB TO usage_limit_GB]
    hiddify-1          | (Background on this error at: https://sqlalche.me/e/20/e3q8)
    hiddify-1          | 2026-01-24 18:59:47.226 | DEBUG    | hiddifypanel.panel.init_db:execute:707 - migrating_db: (MySQLdb.ProgrammingError) (1146, "Table 'hiddifypanel.dailyusage' doesn't exist")
    hiddify-1          | [SQL: update dailyusage set child_id=0 where child_id is NULL]
    hiddify-1          | (Background on this error at: https://sqlalche.me/e/20/f405)
    hiddify-1          | 2026-01-24 18:59:47.227 | DEBUG    | hiddifypanel.panel.init_db:execute:707 - migrating_db: (MySQLdb.ProgrammingError) (1146, "Table 'hiddifypanel.dailyusage' doesn't exist")
    hiddify-1          | [SQL: update dailyusage set admin_id=1 where admin_id is NULL]
    hiddify-1          | (Background on this error at: https://sqlalche.me/e/20/f405)
    hiddify-1          | 2026-01-24 18:59:47.228 | DEBUG    | hiddifypanel.panel.init_db:execute:707 - migrating_db: (MySQLdb.ProgrammingError) (1146, "Table 'hiddifypanel.dailyusage' doesn't exist")
    hiddify-1          | [SQL: update dailyusage set admin_id=1 where admin_id = 0]
    hiddify-1          | (Background on this error at: https://sqlalche.me/e/20/f405)
    hiddify-1          | 2026-01-24 18:59:47.243 | INFO     | hiddifypanel.panel.init_db:upgrade_database:780 - no backup found...
    hiddify-1          | 2026-01-24 18:59:47.252 | WARNING  | hiddifypanel.models.config:hconfig:79 - str db_version not found
    hiddify-1          | 2026-01-24 18:59:47.253 | INFO     | hiddifypanel.panel.init_db:init_db:841 - Updating db from version 0 for node 0
    hiddify-1          | 2026-01-24 18:59:52.611 | INFO     | hiddifypanel.panel.init_db:init_db:851 - Updated successfuly db from version 0 to 1
    hiddify-1          | 2026-01-24 18:59:52.615 | INFO     | hiddifypanel.panel.init_db:init_db:841 - Updating db from version 1 for node 0
    hiddify-1          | 2026-01-24 18:59:52.618 | WARNING  | hiddifypanel.models.config:hconfig:79 - str telegram_lib not found
    hiddify-1          | 2026-01-24 18:59:52.623 | WARNING  | hiddifypanel.models.config:hconfig:79 - str admin_lang not found
    hiddify-1          | 2026-01-24 18:59:52.627 | WARNING  | hiddifypanel.models.config:hconfig:79 - str branding_title not found
    hiddify-1          | 2026-01-24 18:59:52.630 | WARNING  | hiddifypanel.models.config:hconfig:79 - str branding_site not found
    hiddify-1          | 2026-01-24 18:59:52.634 | WARNING  | hiddifypanel.models.config:hconfig:79 - str branding_freetext not found
    hiddify-1          | 2026-01-24 18:59:52.638 | WARNING  | hiddifypanel.models.config:hconfig:73 - bool v2ray_enable not found
    hiddify-1          | 2026-01-24 18:59:52.642 | WARNING  | hiddifypanel.models.config:hconfig:73 - bool is_parent not found
    hiddify-1          | 2026-01-24 18:59:52.645 | WARNING  | hiddifypanel.models.config:hconfig:79 - str parent_panel not found
    hiddify-1          | 2026-01-24 18:59:52.649 | WARNING  | hiddifypanel.models.config:hconfig:79 - str unique_id not found
    hiddify-1          | 2026-01-24 18:59:52.651 | INFO     | hiddifypanel.panel.init_db:init_db:851 - Updated successfuly db from version 1 to 7
    hiddify-1          | 2026-01-24 18:59:52.654 | INFO     | hiddifypanel.panel.init_db:init_db:841 - Updating db from version 7 for node 0
    hiddify-1          | 2026-01-24 18:59:52.657 | INFO     | hiddifypanel.panel.init_db:init_db:851 - Updated successfuly db from version 7 to 9
    hiddify-1          | 2026-01-24 18:59:52.660 | INFO     | hiddifypanel.panel.init_db:init_db:841 - Updating db from version 9 for node 0
    hiddify-1          | 2026-01-24 18:59:52.679 | WARNING  | hiddifypanel.models.config:hconfig:73 - bool tuic_enable not found
    hiddify-1          | 2026-01-24 18:59:52.684 | WARNING  | hiddifypanel.models.config:hconfig:73 - bool shadowtls_enable not found
    hiddify-1          | 2026-01-24 18:59:52.687 | WARNING  | hiddifypanel.models.config:hconfig:79 - str shadowtls_fakedomain not found
    hiddify-1          | 2026-01-24 18:59:52.691 | WARNING  | hiddifypanel.models.config:hconfig:79 - str utls not found
    hiddify-1          | 2026-01-24 18:59:52.695 | WARNING  | hiddifypanel.models.config:hconfig:79 - str telegram_bot_token not found
    hiddify-1          | 2026-01-24 18:59:52.698 | WARNING  | hiddifypanel.models.config:hconfig:79 - str package_mode not found
    hiddify-1          | 2026-01-24 18:59:52.700 | INFO     | hiddifypanel.panel.init_db:init_db:851 - Updated successfuly db from version 9 to 19
    hiddify-1          | 2026-01-24 18:59:52.702 | INFO     | hiddifypanel.panel.init_db:init_db:841 - Updating db from version 19 for node 0
    hiddify-1          | 2026-01-24 18:59:52.704 | INFO     | hiddifypanel.panel.init_db:init_db:851 - Updated successfuly db from version 19 to 20
    hiddify-1          | 2026-01-24 18:59:52.706 | INFO     | hiddifypanel.panel.init_db:init_db:841 - Updating db from version 20 for node 0
    hiddify-1          | 2026-01-24 18:59:52.773 | INFO     | hiddifypanel.panel.init_db:init_db:851 - Updated successfuly db from version 20 to 21
    hiddify-1          | 2026-01-24 18:59:52.776 | INFO     | hiddifypanel.panel.init_db:init_db:841 - Updating db from version 21 for node 0
    hiddify-1          | 2026-01-24 18:59:52.777 | WARNING  | hiddifypanel.models.config:hconfig:79 - str cloudflare not found
    hiddify-1          | 2026-01-24 18:59:52.781 | WARNING  | hiddifypanel.models.config:hconfig:79 - str country not found
    hiddify-1          | 2026-01-24 18:59:52.786 | WARNING  | hiddifypanel.models.config:hconfig:79 - str license not found
    hiddify-1          | 2026-01-24 18:59:52.789 | INFO     | hiddifypanel.panel.init_db:init_db:851 - Updated successfuly db from version 21 to 26
    hiddify-1          | 2026-01-24 18:59:52.791 | INFO     | hiddifypanel.panel.init_db:init_db:841 - Updating db from version 26 for node 0
    hiddify-1          | 2026-01-24 18:59:52.794 | INFO     | hiddifypanel.panel.init_db:init_db:851 - Updated successfuly db from version 26 to 27
    hiddify-1          | 2026-01-24 18:59:52.796 | INFO     | hiddifypanel.panel.init_db:init_db:841 - Updating db from version 27 for node 0
    hiddify-1          | 2026-01-24 18:59:52.798 | WARNING  | hiddifypanel.models.config:hconfig:79 - str reality_short_ids not found
    hiddify-1          | 2026-01-24 18:59:52.926 | WARNING  | hiddifypanel.models.config:hconfig:79 - str reality_private_key not found
    hiddify-1          | 2026-01-24 18:59:52.931 | WARNING  | hiddifypanel.models.config:hconfig:79 - str reality_public_key not found
    hiddify-1          | 2026-01-24 18:59:55.540 | WARNING  | hiddifypanel.models.config:hconfig:79 - str reality_fallback_domain not found
    hiddify-1          | 2026-01-24 18:59:55.544 | WARNING  | hiddifypanel.models.config:hconfig:79 - str reality_server_names not found
    hiddify-1          | 2026-01-24 18:59:55.547 | INFO     | hiddifypanel.panel.init_db:init_db:851 - Updated successfuly db from version 27 to 31
    hiddify-1          | 2026-01-24 18:59:55.549 | INFO     | hiddifypanel.panel.init_db:init_db:841 - Updating db from version 31 for node 0
    hiddify-1          | 2026-01-24 18:59:56.187 | INFO     | hiddifypanel.panel.init_db:init_db:851 - Updated successfuly db from version 31 to 33
    hiddify-1          | 2026-01-24 18:59:56.190 | INFO     | hiddifypanel.panel.init_db:init_db:841 - Updating db from version 33 for node 0
    hiddify-1          | 2026-01-24 18:59:56.192 | WARNING  | hiddifypanel.models.config:hconfig:79 - str dns_server not found
    hiddify-1          | 2026-01-24 18:59:56.195 | WARNING  | hiddifypanel.models.config:hconfig:73 - bool warp_enable not found
    hiddify-1          | 2026-01-24 18:59:56.196 | WARNING  | hiddifypanel.models.config:hconfig:79 - str warp_mode not found
    hiddify-1          | 2026-01-24 18:59:56.200 | WARNING  | hiddifypanel.models.config:hconfig:79 - str warp_plus_code not found
    hiddify-1          | 2026-01-24 18:59:56.203 | INFO     | hiddifypanel.panel.init_db:init_db:851 - Updated successfuly db from version 33 to 38
    hiddify-1          | 2026-01-24 18:59:56.205 | INFO     | hiddifypanel.panel.init_db:init_db:841 - Updating db from version 38 for node 0
    hiddify-1          | 2026-01-24 18:59:56.206 | WARNING  | hiddifypanel.models.config:hconfig:79 - str core_type not found
    hiddify-1          | 2026-01-24 18:59:56.212 | INFO     | hiddifypanel.panel.init_db:init_db:851 - Updated successfuly db from version 38 to 41
    hiddify-1          | 2026-01-24 18:59:56.216 | INFO     | hiddifypanel.panel.init_db:init_db:841 - Updating db from version 41 for node 0
    hiddify-1          | 2026-01-24 18:59:56.217 | WARNING  | hiddifypanel.models.config:hconfig:79 - str telegram_fakedomain not found
    hiddify-1          | 2026-01-24 18:59:56.526 | WARNING  | hiddifypanel.models.config:hconfig:79 - str telegram_fakedomain not found
    hiddify-1          | 2026-01-24 18:59:56.530 | WARNING  | hiddifypanel.models.config:hconfig:79 - str ssfaketls_fakedomain not found
    hiddify-1          | 2026-01-24 18:59:56.858 | WARNING  | hiddifypanel.models.config:hconfig:79 - str ssfaketls_fakedomain not found
    hiddify-1          | 2026-01-24 18:59:56.863 | INFO     | hiddifypanel.panel.init_db:init_db:851 - Updated successfuly db from version 41 to 42
    hiddify-1          | 2026-01-24 18:59:56.865 | INFO     | hiddifypanel.panel.init_db:init_db:841 - Updating db from version 42 for node 0
    hiddify-1          | 2026-01-24 18:59:56.867 | WARNING  | hiddifypanel.models.config:hconfig:79 - str reality_port not found
    hiddify-1          | 2026-01-24 18:59:56.868 | WARNING  | hiddifypanel.models.config:hconfig:79 - str hysteria_port not found
    hiddify-1          | 2026-01-24 18:59:56.869 | WARNING  | hiddifypanel.models.config:hconfig:79 - str tuic_port not found
    hiddify-1          | 2026-01-24 18:59:56.870 | WARNING  | hiddifypanel.models.config:hconfig:79 - str ssh_server_port not found
    hiddify-1          | 2026-01-24 18:59:56.872 | WARNING  | hiddifypanel.models.config:hconfig:79 - str shadowsocks2022_port not found
    hiddify-1          | 2026-01-24 18:59:56.873 | WARNING  | hiddifypanel.models.config:hconfig:79 - str ssh_server_port not found
    hiddify-1          | 2026-01-24 18:59:56.876 | WARNING  | hiddifypanel.models.config:hconfig:73 - bool ssh_server_enable not found
    hiddify-1          | 2026-01-24 18:59:56.879 | INFO     | hiddifypanel.panel.init_db:init_db:851 - Updated successfuly db from version 42 to 45
    hiddify-1          | 2026-01-24 18:59:56.881 | INFO     | hiddifypanel.panel.init_db:init_db:841 - Updating db from version 45 for node 0
    hiddify-1          | 2026-01-24 18:59:56.882 | INFO     | hiddifypanel.panel.init_db:init_db:851 - Updated successfuly db from version 45 to 47
    hiddify-1          | 2026-01-24 18:59:56.885 | INFO     | hiddifypanel.panel.init_db:init_db:841 - Updating db from version 47 for node 0
    hiddify-1          | 2026-01-24 18:59:56.889 | INFO     | hiddifypanel.panel.init_db:init_db:851 - Updated successfuly db from version 47 to 48
    hiddify-1          | 2026-01-24 18:59:56.891 | INFO     | hiddifypanel.panel.init_db:init_db:841 - Updating db from version 48 for node 0
    hiddify-1          | 2026-01-24 18:59:56.893 | INFO     | hiddifypanel.panel.init_db:init_db:851 - Updated successfuly db from version 48 to 49
    hiddify-1          | 2026-01-24 18:59:56.896 | INFO     | hiddifypanel.panel.init_db:init_db:841 - Updating db from version 49 for node 0
    hiddify-1          | 2026-01-24 18:59:56.899 | INFO     | hiddifypanel.panel.init_db:init_db:851 - Updated successfuly db from version 49 to 50
    hiddify-1          | 2026-01-24 18:59:56.901 | INFO     | hiddifypanel.panel.init_db:init_db:841 - Updating db from version 50 for node 0
    hiddify-1          | 2026-01-24 18:59:56.903 | INFO     | hiddifypanel.panel.init_db:init_db:851 - Updated successfuly db from version 50 to 51
    hiddify-1          | 2026-01-24 18:59:56.905 | INFO     | hiddifypanel.panel.init_db:init_db:841 - Updating db from version 51 for node 0
    hiddify-1          | 2026-01-24 18:59:56.978 | INFO     | hiddifypanel.panel.init_db:init_db:851 - Updated successfuly db from version 51 to 52
    hiddify-1          | 2026-01-24 18:59:56.982 | INFO     | hiddifypanel.panel.init_db:init_db:841 - Updating db from version 52 for node 0
    hiddify-1          | 2026-01-24 18:59:56.995 | INFO     | hiddifypanel.panel.init_db:init_db:851 - Updated successfuly db from version 52 to 55
    hiddify-1          | 2026-01-24 18:59:56.999 | INFO     | hiddifypanel.panel.init_db:init_db:841 - Updating db from version 55 for node 0
    hiddify-1          | 2026-01-24 18:59:57.004 | INFO     | hiddifypanel.panel.init_db:init_db:851 - Updated successfuly db from version 55 to 56
    hiddify-1          | 2026-01-24 18:59:57.006 | INFO     | hiddifypanel.panel.init_db:init_db:841 - Updating db from version 56 for node 0
    hiddify-1          | 2026-01-24 18:59:57.007 | WARNING  | hiddifypanel.models.config:hconfig:79 - str warp_sites not found
    hiddify-1          | 2026-01-24 18:59:57.010 | INFO     | hiddifypanel.panel.init_db:init_db:851 - Updated successfuly db from version 56 to 57
    hiddify-1          | 2026-01-24 18:59:57.012 | INFO     | hiddifypanel.panel.init_db:init_db:841 - Updating db from version 57 for node 0
    hiddify-1          | 2026-01-24 18:59:57.016 | INFO     | hiddifypanel.panel.init_db:init_db:851 - Updated successfuly db from version 57 to 59
    hiddify-1          | 2026-01-24 18:59:57.019 | INFO     | hiddifypanel.panel.init_db:init_db:841 - Updating db from version 59 for node 0
    hiddify-1          | 2026-01-24 18:59:57.020 | WARNING  | hiddifypanel.models.config:hconfig:79 - str proxy_path_admin not found
    hiddify-1          | 2026-01-24 18:59:57.024 | WARNING  | hiddifypanel.models.config:hconfig:79 - str proxy_path_client not found
    hiddify-1          | 2026-01-24 18:59:57.027 | INFO     | hiddifypanel.panel.init_db:init_db:851 - Updated successfuly db from version 59 to 60
    hiddify-1          | 2026-01-24 18:59:57.029 | INFO     | hiddifypanel.panel.init_db:init_db:841 - Updating db from version 60 for node 0
    hiddify-1          | 2026-01-24 18:59:57.037 | INFO     | hiddifypanel.panel.init_db:init_db:851 - Updated successfuly db from version 60 to 61
    hiddify-1          | 2026-01-24 18:59:57.040 | INFO     | hiddifypanel.panel.init_db:init_db:841 - Updating db from version 61 for node 0
    hiddify-1          | 2026-01-24 18:59:57.042 | WARNING  | hiddifypanel.models.config:hconfig:73 - bool tls_fragment_enable not found
    hiddify-1          | 2026-01-24 18:59:57.045 | WARNING  | hiddifypanel.models.config:hconfig:79 - str tls_fragment_size not found
    hiddify-1          | 2026-01-24 18:59:57.049 | WARNING  | hiddifypanel.models.config:hconfig:79 - str tls_fragment_sleep not found
    hiddify-1          | 2026-01-24 18:59:57.053 | WARNING  | hiddifypanel.models.config:hconfig:73 - bool tls_mixed_case not found
    hiddify-1          | 2026-01-24 18:59:57.057 | WARNING  | hiddifypanel.models.config:hconfig:73 - bool tls_padding_enable not found
    hiddify-1          | 2026-01-24 18:59:57.060 | WARNING  | hiddifypanel.models.config:hconfig:79 - str tls_padding_length not found
    hiddify-1          | 2026-01-24 18:59:57.063 | INFO     | hiddifypanel.panel.init_db:init_db:851 - Updated successfuly db from version 61 to 62
    hiddify-1          | 2026-01-24 18:59:57.065 | INFO     | hiddifypanel.panel.init_db:init_db:841 - Updating db from version 62 for node 0
    hiddify-1          | 2026-01-24 18:59:57.068 | WARNING  | hiddifypanel.models.config:hconfig:73 - bool hysteria_obfs_enable not found
    hiddify-1          | 2026-01-24 18:59:57.072 | WARNING  | hiddifypanel.models.config:hconfig:79 - str hysteria_up_mbps not found
    hiddify-1          | 2026-01-24 18:59:57.075 | WARNING  | hiddifypanel.models.config:hconfig:79 - str hysteria_down_mbps not found
    hiddify-1          | 2026-01-24 18:59:57.078 | INFO     | hiddifypanel.panel.init_db:init_db:851 - Updated successfuly db from version 62 to 63
    hiddify-1          | 2026-01-24 18:59:57.080 | INFO     | hiddifypanel.panel.init_db:init_db:841 - Updating db from version 63 for node 0
    hiddify-1          | 2026-01-24 18:59:57.081 | WARNING  | hiddifypanel.models.config:hconfig:73 - bool mux_enable not found
    hiddify-1          | 2026-01-24 18:59:57.085 | WARNING  | hiddifypanel.models.config:hconfig:79 - str mux_protocol not found
    hiddify-1          | 2026-01-24 18:59:57.088 | WARNING  | hiddifypanel.models.config:hconfig:79 - str mux_max_connections not found
    hiddify-1          | 2026-01-24 18:59:57.092 | WARNING  | hiddifypanel.models.config:hconfig:79 - str mux_min_streams not found
    hiddify-1          | 2026-01-24 18:59:57.096 | WARNING  | hiddifypanel.models.config:hconfig:79 - str mux_max_streams not found
    hiddify-1          | 2026-01-24 18:59:57.099 | WARNING  | hiddifypanel.models.config:hconfig:73 - bool mux_padding_enable not found
    hiddify-1          | 2026-01-24 18:59:57.103 | WARNING  | hiddifypanel.models.config:hconfig:73 - bool mux_brutal_enable not found
    hiddify-1          | 2026-01-24 18:59:57.107 | WARNING  | hiddifypanel.models.config:hconfig:79 - str mux_brutal_up_mbps not found
    hiddify-1          | 2026-01-24 18:59:57.110 | WARNING  | hiddifypanel.models.config:hconfig:79 - str mux_brutal_down_mbps not found
    hiddify-1          | 2026-01-24 18:59:57.113 | INFO     | hiddifypanel.panel.init_db:init_db:851 - Updated successfuly db from version 63 to 65
    hiddify-1          | 2026-01-24 18:59:57.115 | INFO     | hiddifypanel.panel.init_db:init_db:841 - Updating db from version 65 for node 0
    hiddify-1          | 2026-01-24 18:59:57.183 | WARNING  | hiddifypanel.models.config:hconfig:73 - bool wireguard_enable not found
    hiddify-1          | 2026-01-24 18:59:57.188 | WARNING  | hiddifypanel.models.config:hconfig:79 - str wireguard_port not found
    hiddify-1          | 2026-01-24 18:59:57.192 | WARNING  | hiddifypanel.models.config:hconfig:79 - str wireguard_ipv4 not found
    hiddify-1          | 2026-01-24 18:59:57.196 | WARNING  | hiddifypanel.models.config:hconfig:79 - str wireguard_ipv6 not found
    hiddify-1          | 2026-01-24 18:59:57.203 | WARNING  | hiddifypanel.models.config:hconfig:79 - str wireguard_private_key not found
    hiddify-1          | 2026-01-24 18:59:57.207 | WARNING  | hiddifypanel.models.config:hconfig:79 - str wireguard_public_key not found
    hiddify-1          | 2026-01-24 18:59:57.213 | INFO     | hiddifypanel.panel.init_db:init_db:851 - Updated successfuly db from version 65 to 69
    hiddify-1          | 2026-01-24 18:59:57.217 | INFO     | hiddifypanel.panel.init_db:init_db:841 - Updating db from version 69 for node 0
    hiddify-1          | 2026-01-24 18:59:57.221 | INFO     | hiddifypanel.panel.init_db:init_db:851 - Updated successfuly db from version 69 to 70
    hiddify-1          | 2026-01-24 18:59:57.224 | INFO     | hiddifypanel.panel.init_db:init_db:841 - Updating db from version 70 for node 0
    hiddify-1          | 2026-01-24 18:59:57.230 | INFO     | hiddifypanel.panel.init_db:init_db:851 - Updated successfuly db from version 70 to 71
    hiddify-1          | 2026-01-24 18:59:57.233 | INFO     | hiddifypanel.panel.init_db:init_db:841 - Updating db from version 71 for node 0
    hiddify-1          | 2026-01-24 18:59:57.765 | INFO     | hiddifypanel.panel.init_db:init_db:851 - Updated successfuly db from version 71 to 74
    hiddify-1          | 2026-01-24 18:59:57.767 | INFO     | hiddifypanel.panel.init_db:init_db:841 - Updating db from version 74 for node 0
    hiddify-1          | 2026-01-24 18:59:57.768 | INFO     | hiddifypanel.panel.init_db:init_db:851 - Updated successfuly db from version 74 to 75
    hiddify-1          | 2026-01-24 18:59:57.771 | INFO     | hiddifypanel.panel.init_db:init_db:841 - Updating db from version 75 for node 0
    hiddify-1          | 2026-01-24 18:59:57.771 | INFO     | hiddifypanel.panel.init_db:init_db:851 - Updated successfuly db from version 75 to 77
    hiddify-1          | 2026-01-24 18:59:57.774 | INFO     | hiddifypanel.panel.init_db:init_db:841 - Updating db from version 77 for node 0
    hiddify-1          | 2026-01-24 18:59:57.778 | INFO     | hiddifypanel.panel.init_db:init_db:851 - Updated successfuly db from version 77 to 78
    hiddify-1          | 2026-01-24 18:59:57.780 | INFO     | hiddifypanel.panel.init_db:init_db:841 - Updating db from version 78 for node 0
    hiddify-1          | 2026-01-24 18:59:57.783 | INFO     | hiddifypanel.panel.init_db:init_db:851 - Updated successfuly db from version 78 to 79
    hiddify-1          | 2026-01-24 18:59:57.785 | INFO     | hiddifypanel.panel.init_db:init_db:841 - Updating db from version 79 for node 0
    hiddify-1          | 2026-01-24 18:59:57.791 | INFO     | hiddifypanel.panel.init_db:init_db:851 - Updated successfuly db from version 79 to 80
    hiddify-1          | 2026-01-24 18:59:57.793 | INFO     | hiddifypanel.panel.init_db:init_db:841 - Updating db from version 80 for node 0
    hiddify-1          | 2026-01-24 18:59:57.812 | INFO     | hiddifypanel.panel.init_db:init_db:851 - Updated successfuly db from version 80 to 82
    hiddify-1          | 2026-01-24 18:59:57.814 | INFO     | hiddifypanel.panel.init_db:init_db:841 - Updating db from version 82 for node 0
    hiddify-1          | 2026-01-24 18:59:57.817 | INFO     | hiddifypanel.panel.init_db:init_db:851 - Updated successfuly db from version 82 to 83
    hiddify-1          | 2026-01-24 18:59:57.819 | INFO     | hiddifypanel.panel.init_db:init_db:841 - Updating db from version 83 for node 0
    hiddify-1          | 2026-01-24 18:59:57.820 | INFO     | hiddifypanel.panel.init_db:init_db:851 - Updated successfuly db from version 83 to 84
    hiddify-1          | 2026-01-24 18:59:57.823 | INFO     | hiddifypanel.panel.init_db:init_db:841 - Updating db from version 84 for node 0
    hiddify-1          | 2026-01-24 18:59:57.841 | INFO     | hiddifypanel.panel.init_db:init_db:851 - Updated successfuly db from version 84 to 85
    hiddify-1          | 2026-01-24 18:59:57.843 | INFO     | hiddifypanel.panel.init_db:init_db:841 - Updating db from version 85 for node 0
    hiddify-1          | 2026-01-24 18:59:57.847 | INFO     | hiddifypanel.panel.init_db:init_db:851 - Updated successfuly db from version 85 to 86
    hiddify-1          | 2026-01-24 18:59:57.849 | INFO     | hiddifypanel.panel.init_db:init_db:841 - Updating db from version 86 for node 0
    hiddify-1          | 2026-01-24 18:59:57.855 | INFO     | hiddifypanel.panel.init_db:init_db:851 - Updated successfuly db from version 86 to 89
    hiddify-1          | 2026-01-24 18:59:57.857 | INFO     | hiddifypanel.panel.init_db:init_db:841 - Updating db from version 89 for node 0
    hiddify-1          | 2026-01-24 18:59:57.921 | INFO     | hiddifypanel.panel.init_db:init_db:851 - Updated successfuly db from version 89 to 92
    hiddify-1          | 2026-01-24 18:59:57.924 | INFO     | hiddifypanel.panel.init_db:init_db:841 - Updating db from version 92 for node 0
    hiddify-1          | 2026-01-24 18:59:57.930 | INFO     | hiddifypanel.panel.init_db:init_db:851 - Updated successfuly db from version 92 to 93
    hiddify-1          | 2026-01-24 18:59:57.932 | INFO     | hiddifypanel.panel.init_db:init_db:841 - Updating db from version 93 for node 0
    hiddify-1          | 2026-01-24 18:59:57.935 | INFO     | hiddifypanel.panel.init_db:init_db:851 - Updated successfuly db from version 93 to 94
    hiddify-1          | 2026-01-24 18:59:57.938 | INFO     | hiddifypanel.panel.init_db:init_db:841 - Updating db from version 94 for node 0
    hiddify-1          | 2026-01-24 18:59:57.942 | INFO     | hiddifypanel.panel.init_db:init_db:851 - Updated successfuly db from version 94 to 96
    hiddify-1          | 2026-01-24 18:59:57.944 | INFO     | hiddifypanel.panel.init_db:init_db:841 - Updating db from version 96 for node 0
    hiddify-1          | Generating public/private dsa key pair.
    hiddify-1          | Your identification has been saved in ssh_host_dsa_key
    hiddify-1          | Your public key has been saved in ssh_host_dsa_key.pub
    hiddify-1          | The key fingerprint is:
    hiddify-1          | SHA256:6SEE1kO/S3lsP4xTzLKMLZ5ycPWiTRwHr/LN8WO12Ic hiddify-panel@888b4a907f5b
    hiddify-1          | The key's randomart image is:
    hiddify-1          | +---[DSA 1024]----+
    hiddify-1          | |    oo.          |
    hiddify-1          | |   . .o.  .      |
    hiddify-1          | |      ...  o     |
    hiddify-1          | |     .   =ooo    |
    hiddify-1          | |      . So==+    |
    hiddify-1          | |      .+oO=Bo   .|
    hiddify-1          | |       o=**++ooo.|
    hiddify-1          | |      ..ooo.ooEo.|
    hiddify-1          | |       oo    . ..|
    hiddify-1          | +----[SHA256]-----+
    hiddify-1          | Generating public/private ecdsa key pair.
    hiddify-1          | Your identification has been saved in ssh_host_ecdsa_key
    hiddify-1          | Your public key has been saved in ssh_host_ecdsa_key.pub
    hiddify-1          | The key fingerprint is:
    hiddify-1          | SHA256:zJbM+V+9Rw3wFNOCKkc2mMYAFOZUm7XwDAN9LSroeUw hiddify-panel@888b4a907f5b
    hiddify-1          | The key's randomart image is:
    hiddify-1          | +---[ECDSA 256]---+
    hiddify-1          | |   .B**o.=   .oo |
    hiddify-1          | |   +  .XB.= o o..|
    hiddify-1          | |   .. o++o o + . |
    hiddify-1          | |  . E .=.oo   o  |
    hiddify-1          | | . + .  So     ..|
    hiddify-1          | |  o o  . .     .o|
    hiddify-1          | |   .      .   ...|
    hiddify-1          | |           . .  o|
    hiddify-1          | |            .  ..|
    hiddify-1          | +----[SHA256]-----+
    hiddify-1          | Generating public/private ed25519 key pair.
    hiddify-1          | Your identification has been saved in ssh_host_ed25519_key
    hiddify-1          | Your public key has been saved in ssh_host_ed25519_key.pub
    hiddify-1          | The key fingerprint is:
    hiddify-1          | SHA256:xcwyWFCvIaeHRMReKajjjeyvmo2SntWkDHPH0ueJu1M hiddify-panel@888b4a907f5b
    hiddify-1          | The key's randomart image is:
    hiddify-1          | +--[ED25519 256]--+
    hiddify-1          | |     ++oo.       |
    hiddify-1          | |    ..ooo=       |
    hiddify-1          | |   .o.+o= *      |
    hiddify-1          | | ooo *.* *       |
    hiddify-1          | | o=+* * S        |
    hiddify-1          | |. ++.o E         |
    hiddify-1          | |.oo   o          |
    hiddify-1          | |.*.  o           |
    hiddify-1          | |=.oo..o          |
    hiddify-1          | +----[SHA256]-----+
    hiddify-1          | Generating public/private rsa key pair.
    hiddify-1          | Your identification has been saved in ssh_host_rsa_key
    hiddify-1          | Your public key has been saved in ssh_host_rsa_key.pub
    hiddify-1          | The key fingerprint is:
    hiddify-1          | SHA256:q97Li++HPgNezW1P2TSTwGHXwQNIOjd9XP86AFpi28s hiddify-panel@888b4a907f5b
    hiddify-1          | The key's randomart image is:
    hiddify-1          | +---[RSA 3072]----+
    hiddify-1          | |          ..o==o=|
    hiddify-1          | |          ..o.o*=|
    hiddify-1          | |        oooo . +*|
    hiddify-1          | |       . *o.. . +|
    hiddify-1          | |        So...  ..|
    hiddify-1          | |      . .oo.o... |
    hiddify-1          | |     . o..E. oo  |
    hiddify-1          | |      .=+ .   .. |
    hiddify-1          | |     .++O*       |
    hiddify-1          | +----[SHA256]-----+
    hiddify-1          | 2026-01-24 18:59:58.729 | INFO     | hiddifypanel.panel.init_db:init_db:851 - Updated successfuly db from version 96 to 97
    hiddify-1          | 2026-01-24 18:59:58.732 | INFO     | hiddifypanel.panel.init_db:init_db:841 - Updating db from version 97 for node 0
    hiddify-1          | 2026-01-24 18:59:58.735 | INFO     | hiddifypanel.panel.init_db:init_db:851 - Updated successfuly db from version 97 to 101
    hiddify-1          | 2026-01-24 18:59:58.738 | INFO     | hiddifypanel.panel.init_db:init_db:841 - Updating db from version 101 for node 0
    hiddify-1          | 2026-01-24 18:59:58.740 | INFO     | hiddifypanel.panel.init_db:init_db:851 - Updated successfuly db from version 101 to 103
    hiddify-1          | 2026-01-24 18:59:58.743 | INFO     | hiddifypanel.panel.init_db:init_db:841 - Updating db from version 103 for node 0
    hiddify-1          | 2026-01-24 18:59:59.111 | INFO     | hiddifypanel.panel.init_db:init_db:851 - Updated successfuly db from version 103 to 106
    hiddify-1          | 2026-01-24 18:59:59.114 | INFO     | hiddifypanel.panel.init_db:init_db:841 - Updating db from version 106 for node 0
    hiddify-1          | 2026-01-24 18:59:59.115 | INFO     | hiddifypanel.panel.init_db:init_db:851 - Updated successfuly db from version 106 to 107
    hiddify-1          | 2026-01-24 18:59:59.118 | INFO     | hiddifypanel.panel.init_db:init_db:841 - Updating db from version 107 for node 0
    hiddify-1          | 2026-01-24 18:59:59.120 | INFO     | hiddifypanel.panel.init_db:init_db:851 - Updated successfuly db from version 107 to 108
    hiddify-1          | www.minds.com _ssl.c:1015: The handshake operation timed out
    hiddify-1          | untappd.com [Errno -3] Temporary failure in name resolution
    hiddify-1          | }========================hiddify-panel===================================
    hiddify-1          | ####5####HiddifyPanel####Reading Configs from Panel...####
    hiddify-1          | ####8####Applying Configs####...####
    hiddify-1          | rm: cannot remove '/opt/hiddify-manager/ssl/*.crt': No such file or directory
    hiddify-1          | rm: cannot remove '/opt/hiddify-manager/ssl/*.crt.key': No such file or directory
    hiddify-1          | Rendering: /opt/hiddify-manager/other/ssfaketls/hiddify-ss-faketls.service.j2
    hiddify-1          | Rendering: /opt/hiddify-manager/other/telegram/erlang/install.sh.j2
    hiddify-1          | Rendering: /opt/hiddify-manager/other/telegram/tgo/mtg.toml.j2
    hiddify-1          | Rendering: /opt/hiddify-manager/other/deprecated/shadowtls/shadowtls.conf.j2
    hiddify-1          | Rendering: /opt/hiddify-manager/other/hiddify-cli/run.sh.j2
    hiddify-1          | Rendering: /opt/hiddify-manager/other/wireguard/install.sh.j2
    hiddify-1          | Rendering: /opt/hiddify-manager/singbox/configs/05_inbounds_2000_socks_main.json.j2
    hiddify-1          | Rendering: /opt/hiddify-manager/singbox/configs/05_inbounds_1030_shadowtls.json.j2
    hiddify-1          | Rendering: /opt/hiddify-manager/singbox/configs/05_inbounds_2061_reality_main.json.j2
    hiddify-1          | Rendering: /opt/hiddify-manager/singbox/configs/06_outbounds.json.j2
    hiddify-1          | Rendering: /opt/hiddify-manager/singbox/configs/00_log.json.j2
    hiddify-1          | Rendering: /opt/hiddify-manager/singbox/configs/02_dns.json.j2
    hiddify-1          | Rendering: /opt/hiddify-manager/singbox/configs/05_inbounds_10_ss_new.json.j2
    hiddify-1          | Rendering: /opt/hiddify-manager/singbox/configs/05_inbounds_new.json.j2
    hiddify-1          | Rendering: /opt/hiddify-manager/xray/configs/08_stats.json.j2
    hiddify-1          | Rendering: /opt/hiddify-manager/xray/configs/01_api.json.j2
    hiddify-1          | Rendering: /opt/hiddify-manager/xray/configs/05_inbounds_02_socks_main.json.j2
    hiddify-1          | Rendering: /opt/hiddify-manager/xray/configs/06_outbounds.json.j2
    hiddify-1          | Rendering: /opt/hiddify-manager/xray/configs/07_transport.json.j2
    hiddify-1          | Rendering: /opt/hiddify-manager/xray/configs/05_inbounds_02_kcp_main.json.j2
    hiddify-1          | Rendering: /opt/hiddify-manager/xray/configs/05_inbounds_02_xtls_main.json.j2
    hiddify-1          | Rendering: /opt/hiddify-manager/nginx/parts/common.conf.j2
    hiddify-1          | Rendering: /opt/hiddify-manager/nginx/parts/short-link.conf.j2
    hiddify-1          | Rendering: /opt/hiddify-manager/nginx/parts/def-link.conf.j2
    hiddify-1          | Rendering: /opt/hiddify-manager/nginx/parts/hiddify.conf.j2
    hiddify-1          | Rendering: /opt/hiddify-manager/nginx/parts/proxy_path.conf.j2
    hiddify-1          | Rendering: /opt/hiddify-manager/nginx/conf.d/speedtest.conf.j2
    hiddify-1          | Rendering: /opt/hiddify-manager/nginx/conf.d/xray-base.conf.j2
    hiddify-1          | Rendering: /opt/hiddify-manager/haproxy/haproxy.cfg.j2
    hiddify-1          | Rendering: /opt/hiddify-manager/common/run.sh.j2
    hiddify-1          | Rendering: /opt/hiddify-manager/other/ssh/.env.j2
    hiddify-1          | Rendering: /opt/hiddify-manager/singbox/configs/05_inbounds_2039_vmess_new.json.j2
    hiddify-1          | Rendering: /opt/hiddify-manager/singbox/configs/05_inbounds_4100_hysteria.json.j2
    hiddify-1          | Rendering: /opt/hiddify-manager/xray/configs/03_routing.json.j2
    hiddify-1          | Rendering: /opt/hiddify-manager/nginx/conf.d/singbox-base.conf.j2
    hiddify-1          | Rendering: /opt/hiddify-manager/haproxy/maps/path.j2
    hiddify-1          | Rendering: /opt/hiddify-manager/haproxy/maps/path_h2.j2
    hiddify-1          | Rendering: /opt/hiddify-manager/haproxy/maps/http_domain.j2
    hiddify-1          | Rendering: /opt/hiddify-manager/haproxy/maps/decoy_domain.j2
    hiddify-1          | Rendering: /opt/hiddify-manager/haproxy/maps/sni_h2.j2
    hiddify-1          | Rendering: /opt/hiddify-manager/haproxy/maps/path_v10.j2
    hiddify-1          | Rendering: /opt/hiddify-manager/haproxy/maps/sni.j2
    hiddify-1          | Rendering: /opt/hiddify-manager/other/telegram/install.sh.j2
    hiddify-1          | Rendering: /opt/hiddify-manager/other/telegram/erlang/run.sh.j2
    hiddify-1          | Rendering: /opt/hiddify-manager/other/telegram/python/config.py.j2
    hiddify-1          | Rendering: /opt/hiddify-manager/other/hiddify-cli/install.sh.j2
    hiddify-1          | Rendering: /opt/hiddify-manager/other/v2ray/config-v2ray.json.j2
    hiddify-1          | Rendering: /opt/hiddify-manager/singbox/configs/05_inbounds_4010_tuic.json.j2
    hiddify-1          | Rendering: /opt/hiddify-manager/singbox/configs/05_inbounds_10_ss_ws_new.json.j2
    hiddify-1          | Rendering: /opt/hiddify-manager/xray/configs/04_policy.json.j2
    hiddify-1          | Rendering: /opt/hiddify-manager/xray/configs/09_reverse.json.j2
    hiddify-1          | Rendering: /opt/hiddify-manager/xray/configs/05_inbounds_03_dispatcher_h2.json.j2
    hiddify-1          | Rendering: /opt/hiddify-manager/xray/configs/05_inbounds_02_reality_main.json.j2
    hiddify-1          | Rendering: /opt/hiddify-manager/xray/configs/05_inbounds_01_api.json.j2
    hiddify-1          | Rendering: /opt/hiddify-manager/xray/configs/02_dns.json.j2
    hiddify-1          | Rendering: /opt/hiddify-manager/xray/configs/05_inbounds_new.json.j2
    hiddify-1          | Rendering: /opt/hiddify-manager/other/telegram/run.sh.j2
    hiddify-1          | Rendering: /opt/hiddify-manager/other/telegram/erlang/prod-sys.config.j2
    hiddify-1          | Rendering: /opt/hiddify-manager/other/telegram/orig/tgproxy_run.sh.j2
    hiddify-1          | Rendering: /opt/hiddify-manager/other/warp/wireguard/run.sh.j2
    hiddify-1          | Rendering: /opt/hiddify-manager/other/wireguard/run.sh.j2
    hiddify-1          | Rendering: /opt/hiddify-manager/singbox/configs/01_api.json.j2
    hiddify-1          | Rendering: /opt/hiddify-manager/singbox/configs/03_routing.json.j2
    hiddify-1          | Rendering: /opt/hiddify-manager/xray/configs/00_log.json.j2
    hiddify-1          | Rendering: /opt/hiddify-manager/xray/configs/05_inbounds_03_dispatcher.json.j2
    hiddify-1          | Rendering: /opt/hiddify-manager/nginx/nginx.conf.j2
    hiddify-1          | Rendering: /opt/hiddify-manager/nginx/parts/proxy_to_panel.conf.j2
    hiddify-1          | Rendering: /opt/hiddify-manager/nginx/parts/proxy_to_static.conf.j2
    hiddify-1          | ####10####Configuring...####System and Firewall settings####
    hiddify-1          | ####15####Applying...####Nginx####
    hiddify-1          | ===run.sh common
    hiddify-1          | ####35####Applying...####Personal SpeedTest####
    hiddify-1          | ======================nginx====================================={
    hiddify-1          | ####20####Applying...####Haproxy for Spliting Traffic####
    hiddify-1          | ======================haproxy====================================={
    hiddify-1          | ===run.sh nginx
    hiddify-1          | ===run.sh haproxy
    hiddify-1          | ####40####Applying...####Telegram Proxy####
    hiddify-1          | ####45####Applying...####FakeTlS Proxy####
    hiddify-1          | ####55####Applying...####SSH Proxy####
    hiddify-1          | ####70####Applying...####Warp####
    hiddify-1          | Error: Key not found: ssfaketls_enable
    hiddify-1          | ======================other/ssfaketls====================================={
    hiddify-1          | ===run.sh other/ssfaketls
    hiddify-1          | adding rule INPUT -p tcp --dport 22 -j ACCEPT
    hiddify-1          | adding rule INPUT -p tcp --dport 22 -j ACCEPT
    hiddify-1          | ======================other/telegram====================================={
    hiddify-1          | ===disable.sh other/telegram
    hiddify-1          | ======================other/ssh====================================={
    hiddify-1          | ===run.sh other/ssh
    hiddify-1          | ======================other/speedtest====================================={
    hiddify-1          | }========================other/speedtest===================================
    hiddify-1          | ####75####Applying...####Xray####
    hiddify-1          | ####80####Applying...####HiddifyCli####
    hiddify-1          | ####85####Applying...####Wireguard####
    hiddify-1          | ####95####Applying...####Singbox####
    hiddify-1          | ####98####Applying...####Almost Finished####
    hiddify-1          | ======================xray====================================={
    hiddify-1          | ===run.sh xray
    hiddify-1          | ======================other/warp====================================={
    hiddify-1          | ===disable.sh other/warp
    hiddify-1          | ======================singbox====================================={
    hiddify-1          | ===run.sh singbox
    hiddify-1          | adding rule INPUT -p tcp -m tcp --dport 22 -m conntrack --ctstate NEW -j ACCEPT
    hiddify-1          | adding rule INPUT -p tcp -m tcp --dport 22 -m conntrack --ctstate NEW -j ACCEPT
    hiddify-1          | adding rule INPUT -p tcp --dport 80 -j ACCEPT
    hiddify-1          | Setting permissions on /opt/hiddify-manager/nginx/parts/short-link.conf
    hiddify-1          | ======================other/wireguard====================================={
    hiddify-1          | ===run.sh other/wireguard
    hiddify-1          | ======================other/hiddify-cli====================================={
    hiddify-1          | ===run.sh other/hiddify-cli
    hiddify-1          | sed: can't read /etc/wireguard/hiddifywg.conf: No such file or directory
    hiddify-1          | adding rule INPUT -p tcp --dport 80 -j ACCEPT
    hiddify-1          | Setting permissions on /opt/hiddify-manager/nginx/parts
    hiddify-1          | chmod: cannot access '/etc/wireguard/hiddifywg.conf': No such file or directory
    hiddify-1          | chown: invalid user: 'hiddify-cli'
    hiddify-1          | Setting permissions on /opt/hiddify-manager/nginx
    hiddify-1          | adding rule INPUT -p tcp -m tcp --dport 80 -m conntrack --ctstate NEW -j ACCEPT
    hiddify-1          | chown: invalid user: 'hiddify-cli'
    hiddify-1          | adding rule INPUT -p tcp -m tcp --dport 80 -m conntrack --ctstate NEW -j ACCEPT
    hiddify-1          | adding rule INPUT -p tcp --dport 443 -j ACCEPT
    hiddify-1          | adding rule INPUT -p tcp --dport 443 -j ACCEPT
    hiddify-1          | adding rule INPUT -p tcp -m tcp --dport 443 -m conntrack --ctstate NEW -j ACCEPT
    hiddify-1          | adding rule INPUT -p tcp -m tcp --dport 443 -m conntrack --ctstate NEW -j ACCEPT
    hiddify-1          | Unable to retrieve current interface configuration: No such device
    hiddify-1          | adding rule INPUT -p udp --dport 443 -j ACCEPT
    hiddify-1          | adding rule INPUT -p udp --dport 443 -j ACCEPT
    hiddify-1          | adding rule INPUT -p udp -m udp --dport 443 -m conntrack --ctstate NEW -j ACCEPT
    hiddify-1          | adding rule INPUT -p udp -m udp --dport 443 -m conntrack --ctstate NEW -j ACCEPT
    hiddify-1          | adding rule INPUT -p udp --dport 53 -j ACCEPT
    hiddify-1          | adding rule INPUT -p udp --dport 53 -j ACCEPT
    hiddify-1          | adding rule INPUT -p udp -m udp --dport 53 -m conntrack --ctstate NEW -j ACCEPT
    hiddify-1          | adding rule INPUT -p udp -m udp --dport 53 -m conntrack --ctstate NEW -j ACCEPT
    hiddify-1          | adding rule INPUT -p tcp --dport 53 -j ACCEPT
    hiddify-1          | adding rule INPUT -p tcp --dport 53 -j ACCEPT
    hiddify-1          | adding rule INPUT -p tcp -m tcp --dport 53 -m conntrack --ctstate NEW -j ACCEPT
    hiddify-1          | adding rule INPUT -p tcp -m tcp --dport 53 -m conntrack --ctstate NEW -j ACCEPT
    hiddify-1          | adding rule INPUT -p udp --dport 19493 -j ACCEPT
    hiddify-1          | adding rule INPUT -p udp --dport 19493 -j ACCEPT
    hiddify-1          | adding rule INPUT -p udp -m udp --dport 19493 -m conntrack --ctstate NEW -j ACCEPT
    hiddify-1          | adding rule INPUT -p udp -m udp --dport 19493 -m conntrack --ctstate NEW -j ACCEPT
    hiddify-1          | adding rule INPUT -p udp -m conntrack --ctstatus SEEN_REPLY,ASSURED,CONFIRMED -j ACCEPT
    hiddify-1          | adding rule INPUT -p udp -m conntrack --ctstatus SEEN_REPLY,ASSURED,CONFIRMED -j ACCEPT
    hiddify-1          | adding rule OUTPUT -p udp -j ACCEPT
    hiddify-1          | adding rule OUTPUT -p udp -j ACCEPT
    hiddify-1          | adding rule OUTPUT -p tcp -j ACCEPT
    hiddify-1          | adding rule OUTPUT -p tcp -j ACCEPT
    hiddify-1          | adding rule INPUT -i lo -j ACCEPT
    hiddify-1          | adding rule INPUT -i lo -j ACCEPT
    hiddify-1          | adding rule INPUT -p udp --dport 29361 -j ACCEPT
    hiddify-1          | adding rule INPUT -p udp --dport 29361 -j ACCEPT
    hiddify-1          | adding rule INPUT -p udp -m udp --dport 29361 -m conntrack --ctstate NEW -j ACCEPT
    hiddify-1          | adding rule INPUT -p udp -m udp --dport 29361 -m conntrack --ctstate NEW -j ACCEPT
    hiddify-1          | adding rule INPUT -p udp --dport 14507 -j ACCEPT
    hiddify-1          | adding rule INPUT -p udp --dport 14507 -j ACCEPT
    hiddify-1          | ERROR:systemctl:Unit hiddify-cli.service not found.
    hiddify-1          | adding rule INPUT -p udp -m udp --dport 14507 -m conntrack --ctstate NEW -j ACCEPT
    hiddify-1          | adding rule INPUT -p udp -m udp --dport 14507 -m conntrack --ctstate NEW -j ACCEPT
    hiddify-1          | adding rule INPUT -p udp --dport 29362 -j ACCEPT
    hiddify-1          | adding rule INPUT -p udp --dport 29362 -j ACCEPT
    hiddify-1          | adding rule INPUT -p udp -m udp --dport 29362 -m conntrack --ctstate NEW -j ACCEPT
    hiddify-1          | adding rule INPUT -p udp -m udp --dport 29362 -m conntrack --ctstate NEW -j ACCEPT
    hiddify-1          | adding rule INPUT -p udp --dport 14508 -j ACCEPT
    hiddify-1          | adding rule INPUT -p udp --dport 14508 -j ACCEPT
    hiddify-1          | adding rule INPUT -p udp -m udp --dport 14508 -m conntrack --ctstate NEW -j ACCEPT
    hiddify-1          | adding rule INPUT -p udp -m udp --dport 14508 -m conntrack --ctstate NEW -j ACCEPT
    hiddify-1          | adding rule INPUT -p icmp -j ACCEPT
    hiddify-1          | adding rule INPUT -p ipv6-icmp -j ACCEPT
    hiddify-1          | Service not found or not running
    hiddify-1          | Service not found or not running
    hiddify-1          | adding rule INPUT -m state --state ESTABLISHED,RELATED -j ACCEPT
    hiddify-1          | adding rule INPUT -m state --state ESTABLISHED,RELATED -j ACCEPT
    hiddify-1          | adding rule INPUT -m conntrack --ctstate RELATED,ESTABLISHED -j ACCEPT
    hiddify-1          | adding rule INPUT -m conntrack --ctstate RELATED,ESTABLISHED -j ACCEPT
    hiddify-1          | adding rule INPUT -p tcp --dport 11744 -j ACCEPT
    hiddify-1          | adding rule INPUT -p tcp --dport 11744 -j ACCEPT
    hiddify-1          | adding rule INPUT -p tcp -m tcp --dport 11744 -m conntrack --ctstate NEW -j ACCEPT
    hiddify-1          | adding rule INPUT -p tcp -m tcp --dport 11744 -m conntrack --ctstate NEW -j ACCEPT
    hiddify-1          | grep: /etc/motd: No such file or directory
    hiddify-1          | ERROR:systemctl:Unit sshd.service not found.
    hiddify-1          | Ignoring xray test
    hiddify-1          | }========================other/hiddify-cli===================================
    hiddify-1          | Setting permissions on /opt/hiddify-manager/singbox/configs/01_api.json
    hiddify-1          | Setting permissions on /opt/hiddify-manager/singbox/configs
    hiddify-1          | Setting permissions on /opt/hiddify-manager/singbox
    hiddify-1          | ignoring singbox test
    hiddify-1          | }========================other/wireguard===================================
    hiddify-1          | ERROR:systemctl:  hiddify-ss-faketls.service: Service Executable path is not absolute.
    hiddify-1          | ERROR:systemctl: hiddify-ss-faketls.service: Exec is not an absolute path:  ExecStart=obfs-server -s 127.0.0.1 -p 1010 -r 127.0.0.1:41721 --obfs tls --fast-open --failover cdn.fbsbx.com:443
    hiddify-1          | ERROR:systemctl: hiddify-ss-faketls.service: Exec command does not exist: (ExecStart) obfs-server
    hiddify-1          | ERROR:systemctl: hiddify-ss-faketls.service: but this does exist:            /usr/bin/obfs-server
    hiddify-1          | ERROR:systemctl: !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
    hiddify-1          | ERROR:systemctl: The SystemD ExecXY commands must always be absolute paths by definition.
    hiddify-1          | }========================other/warp===================================
    hiddify-1          | }========================nginx===================================
    hiddify-1          | }========================other/ssh===================================
    hiddify-1          | ERROR:systemctl: Oops, 1 executable paths were not found in the current environment. Refusing.
    hiddify-1          | }========================xray===================================
    hiddify-1          | }========================other/telegram===================================
    hiddify-1          | }========================haproxy===================================
    hiddify-1          | ####30####Applying...####Getting Certificates####
    hiddify-1          | ======================acme.sh====================================={
    hiddify-1          | ===run.sh acme.sh
    hiddify-1          | resolving domain 95.161.0.12 : IP= IPv6=   ServerIP=95.161.0.12 ServerIPv6=
    hiddify-1          | maybe it is an error! make sure that it is correct
    hiddify-1          | ./cert_utils.sh: line 56: alias: --issue: not found
    hiddify-1          | ./cert_utils.sh: line 56: alias: -w: not found
    hiddify-1          | ./cert_utils.sh: line 56: alias: /opt/hiddify-manager/acme.sh/www/: not found
    hiddify-1          | ./cert_utils.sh: line 56: alias: --log: not found
    hiddify-1          | ./cert_utils.sh: line 56: alias: /opt/hiddify-manager/acme.sh/../log/system/acme.log: not found
    hiddify-1          | ./cert_utils.sh: line 56: alias: --pre-hook: not found
    hiddify-1          | ./cert_utils.sh: line 56: alias: systemctl restart hiddify-nginx: not found
    hiddify-1          | ./cert_utils.sh: line 58: acmecmd: command not found
    hiddify-1          | [Sat Jan 24 19:00:18 UTC 2026] The domain '95.161.0.12' is not a cert name. You must use the cert name to specify the cert to install.
    hiddify-1          | [Sat Jan 24 19:00:18 UTC 2026] Cannot find path: '/opt/hiddify-manager/acme.sh/lib/certs/95.161.0.12'
    hiddify-1          | writing RSA key
    hiddify-1          | }========================singbox===================================
    hiddify-1          | ERROR:systemctl: !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
    hiddify-1          | }========================other/ssfaketls===================================
    hiddify-1          | resolving domain 95.161.0.12.sslip.io : IP=95.161.0.12 IPv6=   ServerIP=95.161.0.12 ServerIPv6=
    hiddify-1          | ./cert_utils.sh: line 56: alias: --issue: not found
    hiddify-1          | ./cert_utils.sh: line 56: alias: -w: not found
    hiddify-1          | ./cert_utils.sh: line 56: alias: /opt/hiddify-manager/acme.sh/www/: not found
    hiddify-1          | ./cert_utils.sh: line 56: alias: --log: not found
    hiddify-1          | ./cert_utils.sh: line 56: alias: /opt/hiddify-manager/acme.sh/../log/system/acme.log: not found
    hiddify-1          | ./cert_utils.sh: line 56: alias: --pre-hook: not found
    hiddify-1          | ./cert_utils.sh: line 56: alias: systemctl restart hiddify-nginx: not found
    hiddify-1          | ./cert_utils.sh: line 62: acmecmd: command not found
    hiddify-1          | ./cert_utils.sh: line 64: acmecmd: command not found
    hiddify-1          | [Sat Jan 24 19:00:20 UTC 2026] The domain '95.161.0.12.sslip.io' is not a cert name. You must use the cert name to specify the cert to install.
    hiddify-1          | [Sat Jan 24 19:00:20 UTC 2026] Cannot find path: '/opt/hiddify-manager/acme.sh/lib/certs/95.161.0.12.sslip.io'
    hiddify-1          | writing RSA key
    hiddify-1          | ip6tables-restore: line 39 failed
    hiddify-1          |  * Reloading configuration files for periodic command scheduler cron
    hiddify-1          |    ...done.
    hiddify-1          | writing RSA key
    hiddify-1          | writing RSA key
    hiddify-1          | writing RSA key
    hiddify-1          | }========================acme.sh===================================
    hiddify-1          | ---------------------Finished!------------------------
    mariadb_container  | 2026-01-24 19:00:27 5 [Warning] Aborted connection 5 to db: 'hiddifypanel' user: 'hiddifypanel' host: '172.18.0.4' (Got an error reading communication packets)
    hiddify-1          | ####100####Applying...####Done####
    hiddify-1          | ----------------------------------------------------------------
    hiddify-1          | - Global IP:
    hiddify-1          |     "country"      : "XXXXXX",
    hiddify-1          |     "city"         : "XXXXXX",
    hiddify-1          |     "org"          : "XXXXXX",
    hiddify-1          |     "query"        : "95.16.0.12"
    hiddify-1          | ----------------------------------------------------------------
    hiddify-1          | - Services Status:
    hiddify-1          |     hiddify-nginx                                          active
    hiddify-1          |     hiddify-ss-faketls                                     failed
    hiddify-1          |     hiddify-panel-background-tasks                         active
    hiddify-1          |     hiddify-ssh-liberty-bridge                             active
    hiddify-1          |     hiddify-panel                                          active
    hiddify-1          |     hiddify-haproxy                                        active
    hiddify-1          |     hiddify-singbox                                        failed
    hiddify-1          |     hiddify-xray                                           active
    hiddify-1          | ----------------------------------------------------------------
    hiddify-1          | Hiddify is started!!!! in 5 seconds you will see the system logs
    hiddify-1          | ==> /opt/hiddify-manager/log/system/0-install.log <==
    hiddify-1          | writing RSA key
    hiddify-1          | ip6tables-restore: line 39 failed
    hiddify-1          |  * Reloading configuration files for periodic command scheduler cron
    hiddify-1          |    ...done.
    hiddify-1          | writing RSA key
    hiddify-1          | writing RSA key
    hiddify-1          | writing RSA key
    hiddify-1          | }========================acme.sh===================================
    hiddify-1          | ---------------------Finished!------------------------
    hiddify-1          | ####100####Applying...####Done####
    hiddify-1          |
    hiddify-1          | ==> /opt/hiddify-manager/log/system/hiddify_panel.err.log <==
    hiddify-1          |
    hiddify-1          | ==> /opt/hiddify-manager/log/system/hiddify_panel.out.log <==
    hiddify-1          |
    hiddify-1          | ==> /opt/hiddify-manager/log/system/hiddify_panel_background_tasks.err.log <==
    hiddify-1          | [2026-01-24 19:00:10,491: DEBUG/MainProcess] | Consumer: Starting Control
    hiddify-1          | [2026-01-24 19:00:10,493: DEBUG/MainProcess] ^-- substep ok
    hiddify-1          | [2026-01-24 19:00:10,493: DEBUG/MainProcess] | Consumer: Starting Heart
    hiddify-1          | [2026-01-24 19:00:10,494: DEBUG/MainProcess] ^-- substep ok
    hiddify-1          | [2026-01-24 19:00:10,494: DEBUG/MainProcess] | Consumer: Starting Gossip
    hiddify-1          | [2026-01-24 19:00:10,496: DEBUG/MainProcess] ^-- substep ok
    hiddify-1          | [2026-01-24 19:00:10,496: DEBUG/MainProcess] | Consumer: Starting event loop
    hiddify-1          | [2026-01-24 19:00:10,496: DEBUG/MainProcess] | Worker: Hub.register Pool...
    hiddify-1          | [2026-01-24 19:00:10,496: INFO/MainProcess] celery@888b4a907f5b ready.
    hiddify-1          | [2026-01-24 19:00:10,496: DEBUG/MainProcess] basic.qos: prefetch_count->4
    hiddify-1          |
    hiddify-1          | ==> /opt/hiddify-manager/log/system/hiddify_panel_background_tasks.out.log <==
    hiddify-1          |   . celery.chain
    hiddify-1          |   . celery.chord
    hiddify-1          |   . celery.chord_unlock
    hiddify-1          |   . celery.chunks
    hiddify-1          |   . celery.group
    hiddify-1          |   . celery.map
    hiddify-1          |   . celery.starmap
    hiddify-1          |   . hiddifypanel.panel.cli.backup_task
    hiddify-1          |   . hiddifypanel.panel.usage.update_local_usage
    hiddify-1          |
    hiddify-1          |
    hiddify-1          | ==> /opt/hiddify-manager/log/system/installer.log <==
    hiddify-1          | Failed to connect to bus: Host is down
    hiddify-1          | }========================acme.sh===================================
    hiddify-1          | ---------------------Finished!------------------------
    hiddify-1          | System has not been booted with systemd as init system (PID 1). Can't operate.
    hiddify-1          | Failed to connect to bus: Host is down
    hiddify-1          | System has not been booted with systemd as init system (PID 1). Can't operate.
    hiddify-1          | Failed to connect to bus: Host is down
    hiddify-1          | ####100####Installing...####Done####
    hiddify-1          | installing in docker mode finishs
    hiddify-1          | ---------------------Finished!------------------------
    hiddify-1          |
    hiddify-1          | ==> /opt/hiddify-manager/log/system/panel.log <==
    hiddify-1          |
    hiddify-1          | ==> /opt/hiddify-manager/log/system/ss-faketls.err.log <==
    hiddify-1          | ERROR:systemctl:('obfs-server' '-s' '127.0.0.1' '-p' '1010' '-r' '127.0.0.1:41721' '--obfs' 'tls' '--fast-open' '--failover' 'cdn.fbsbx.com:443'): [Errno 2] No such file or directory: 'obfs-server'
    hiddify-1          |
    hiddify-1          | ==> /opt/hiddify-manager/log/system/ss-faketls.out.log <==
    hiddify-1          |
    hiddify-1          | ==> /opt/hiddify-manager/log/system/status.log <==
    hiddify-1          | - Services Status:
    hiddify-1          |     hiddify-nginx                                          active
    hiddify-1          |     hiddify-ss-faketls                                     failed
    hiddify-1          |     hiddify-panel-background-tasks                         active
    hiddify-1          |     hiddify-ssh-liberty-bridge                             active
    hiddify-1          |     hiddify-panel                                          active
    hiddify-1          |     hiddify-haproxy                                        active
    hiddify-1          |     hiddify-singbox                                        failed
    hiddify-1          |     hiddify-xray                                           active
    hiddify-1          | ----------------------------------------------------------------
    hiddify-1          |
    hiddify-1          | ==> /opt/hiddify-manager/log/system/hiddify_panel_background_tasks.err.log <==
    hiddify-1          | [2026-01-24 19:01:09,485: DEBUG/Beat] beat: Synchronizing schedule...
    hiddify-1          | [2026-01-24 19:01:09,502: INFO/Beat] Scheduler: Sending due task update usage (hiddifypanel.panel.usage.update_local_usage)
    hiddify-1          | [2026-01-24 19:01:09,506: DEBUG/Beat] hiddifypanel.panel.usage.update_local_usage sent. id->d123b409-9541-4c91-bf6a-e2b34417e15e
    hiddify-1          | [2026-01-24 19:01:09,506: DEBUG/Beat] beat: Waking up in 59.98 seconds.
    hiddify-1          | [2026-01-24 19:01:09,507: INFO/MainProcess] Task hiddifypanel.panel.usage.update_local_usage[d123b409-9541-4c91-bf6a-e2b34417e15e] received
    hiddify-1          | [2026-01-24 19:01:09,507: DEBUG/MainProcess] TaskPool: Apply <function fast_trace_task at 0x754c97281800> (args:('hiddifypanel.panel.usage.update_local_usage', 'd123b409-9541-4c91-bf6a-e2b34417e15e', {'lang': 'py', 'task': 'hiddifypanel.panel.usage.update_local_usage', 'id': 'd123b409-9541-4c91-bf6a-e2b34417e15e', 'shadow': None, 'eta': None, 'expires': None, 'group': None, 'group_index': None, 'retries': 0, 'timelimit': [None, None], 'root_id': 'd123b409-9541-4c91-bf6a-e2b34417e15e', 'parent_id': None, 'argsrepr': '()', 'kwargsrepr': '{}', 'origin': 'gen384@888b4a907f5b', 'ignore_result': False, 'replaced_task_nesting': 0, 'stamped_headers': None, 'stamps': {}, 'properties': {'correlation_id': 'd123b409-9541-4c91-bf6a-e2b34417e15e', 'reply_to': '0b5a0d73-2f0d-3574-a7c5-8161a649d463', 'delivery_mode': 2, 'delivery_info': {'exchange': '', 'routing_key': 'celery'}, 'priority': 0, 'body_encoding': 'base64', 'delivery_tag': 'd4278c21-3a50-4c53-a850-dd4bd2fa058c'}, 'reply_to': '0b5a0d73-2f0d-3574-a7c5-8161a649d463', 'correlation_id': 'd123b409-9541-4c91-bf6a-e2b34417e15e', 'hostname': 'celery@888b4a907f5b',... kwargs:{})
    hiddify-1          | [2026-01-24 19:01:09,556: WARNING/MainProcess] <hiddifypanel.drivers.singbox_api.SingboxApi object at 0x754c93c64c20>
    hiddify-1          | [2026-01-24 19:01:09,556: WARNING/MainProcess] ERROR! SingboxApi has error in update usage <_InactiveRpcError of RPC that terminated with:
    hiddify-1          |    status = StatusCode.UNAVAILABLE
    hiddify-1          |    details = "failed to connect to all addresses; last error: UNKNOWN: ipv4:127.0.0.1:10086: Failed to connect to remote host: connect: Connection refused (111)"
    hiddify-1          |    debug_error_string = "UNKNOWN:Error received from peer  {grpc_message:"failed to connect to all addresses; last error: UNKNOWN: ipv4:127.0.0.1:10086: Failed to connect to remote host: connect: Connection refused (111)", grpc_status:14}"
    hiddify-1          | >
    hiddify-1          | 2026-01-24 19:01:09.556 | ERROR    | hiddifypanel.drivers.user_driver:get_users_usage:35 - ERROR! SingboxApi has error in update usage <_InactiveRpcError of RPC that terminated with:
    hiddify-1          |    status = StatusCode.UNAVAILABLE
    hiddify-1          |    details = "failed to connect to all addresses; last error: UNKNOWN: ipv4:127.0.0.1:10086: Failed to connect to remote host: connect: Connection refused (111)"
    hiddify-1          |    debug_error_string = "UNKNOWN:Error received from peer  {grpc_message:"failed to connect to all addresses; last error: UNKNOWN: ipv4:127.0.0.1:10086: Failed to connect to remote host: connect: Connection refused (111)", grpc_status:14}"
    hiddify-1          | >
    hiddify-1          | Traceback (most recent call last):
    hiddify-1          |
    hiddify-1          |   File "<frozen runpy>", line 198, in _run_module_as_main
    hiddify-1          |   File "<frozen runpy>", line 88, in _run_code
    hiddify-1          |   File "/opt/hiddify-manager/.venv313/lib/python3.13/site-packages/celery/__main__.py", line 19, in <module>
    hiddify-1          |     main()
    hiddify-1          |   File "/opt/hiddify-manager/.venv313/lib/python3.13/site-packages/celery/__main__.py", line 15, in main
    hiddify-1          |     sys.exit(_main())
    hiddify-1          |   File "/opt/hiddify-manager/.venv313/lib/python3.13/site-packages/celery/bin/celery.py", line 227, in main
    hiddify-1          |     return celery(auto_envvar_prefix="CELERY")
    hiddify-1          |   File "/opt/hiddify-manager/.venv313/lib/python3.13/site-packages/click/core.py", line 1485, in __call__
    hiddify-1          |     return self.main(*args, **kwargs)
    hiddify-1          |   File "/opt/hiddify-manager/.venv313/lib/python3.13/site-packages/click/core.py", line 1406, in main
    hiddify-1          |     rv = self.invoke(ctx)
    hiddify-1          |   File "/opt/hiddify-manager/.venv313/lib/python3.13/site-packages/click/core.py", line 1873, in invoke
    hiddify-1          |     return _process_result(sub_ctx.command.invoke(sub_ctx))
    hiddify-1          |   File "/opt/hiddify-manager/.venv313/lib/python3.13/site-packages/click/core.py", line 1269, in invoke
    hiddify-1          |     return ctx.invoke(self.callback, **ctx.params)
    hiddify-1          |   File "/opt/hiddify-manager/.venv313/lib/python3.13/site-packages/click/core.py", line 824, in invoke
    hiddify-1          |     return callback(*args, **kwargs)
    hiddify-1          |   File "/opt/hiddify-manager/.venv313/lib/python3.13/site-packages/click/decorators.py", line 34, in new_func
    hiddify-1          |     return f(get_current_context(), *args, **kwargs)
    hiddify-1          |   File "/opt/hiddify-manager/.venv313/lib/python3.13/site-packages/celery/bin/base.py", line 135, in caller
    hiddify-1          |     return f(ctx, *args, **kwargs)
    hiddify-1          |   File "/opt/hiddify-manager/.venv313/lib/python3.13/site-packages/celery/bin/worker.py", line 367, in worker
    hiddify-1          |     worker.start()
    hiddify-1          |   File "/opt/hiddify-manager/.venv313/lib/python3.13/site-packages/celery/worker/worker.py", line 203, in start
    hiddify-1          |     self.blueprint.start(self)
    hiddify-1          |   File "/opt/hiddify-manager/.venv313/lib/python3.13/site-packages/celery/bootsteps.py", line 116, in start
    hiddify-1          |     step.start(parent)
    hiddify-1          |   File "/opt/hiddify-manager/.venv313/lib/python3.13/site-packages/celery/bootsteps.py", line 365, in start
    hiddify-1          |     return self.obj.start()
    hiddify-1          |   File "/opt/hiddify-manager/.venv313/lib/python3.13/site-packages/celery/worker/consumer/consumer.py", line 346, in start
    hiddify-1          |     blueprint.start(self)
    hiddify-1          |   File "/opt/hiddify-manager/.venv313/lib/python3.13/site-packages/celery/bootsteps.py", line 116, in start
    hiddify-1          |     step.start(parent)
    hiddify-1          |   File "/opt/hiddify-manager/.venv313/lib/python3.13/site-packages/celery/worker/consumer/consumer.py", line 788, in start
    hiddify-1          |     c.loop(*c.loop_args())
    hiddify-1          |   File "/opt/hiddify-manager/.venv313/lib/python3.13/site-packages/celery/worker/loops.py", line 96, in asynloop
    hiddify-1          |     next(loop)
    hiddify-1          |   File "/opt/hiddify-manager/.venv313/lib/python3.13/site-packages/kombu/asynchronous/hub.py", line 377, in create_loop
    hiddify-1          |     cb(*cbargs)
    hiddify-1          |   File "/opt/hiddify-manager/.venv313/lib/python3.13/site-packages/kombu/transport/redis.py", line 1394, in on_readable
    hiddify-1          |     self.cycle.on_readable(fileno)
    hiddify-1          |   File "/opt/hiddify-manager/.venv313/lib/python3.13/site-packages/kombu/transport/redis.py", line 579, in on_readable
    hiddify-1          |     chan.handlers[type]()
    hiddify-1          |   File "/opt/hiddify-manager/.venv313/lib/python3.13/site-packages/kombu/transport/redis.py", line 994, in _brpop_read
    hiddify-1          |     self.connection._deliver(loads(bytes_to_str(item)), dest)
    hiddify-1          |   File "/opt/hiddify-manager/.venv313/lib/python3.13/site-packages/kombu/transport/virtual/base.py", line 1017, in _deliver
    hiddify-1          |     callback(message)
    hiddify-1          |   File "/opt/hiddify-manager/.venv313/lib/python3.13/site-packages/kombu/transport/virtual/base.py", line 639, in _callback
    hiddify-1          |     return callback(message)
    hiddify-1          |   File "/opt/hiddify-manager/.venv313/lib/python3.13/site-packages/kombu/messaging.py", line 668, in _receive_callback
    hiddify-1          |     return on_m(message) if on_m else self.receive(decoded, message)
    hiddify-1          |   File "/opt/hiddify-manager/.venv313/lib/python3.13/site-packages/celery/worker/consumer/consumer.py", line 694, in on_task_received
    hiddify-1          |     strategy(
    hiddify-1          |   File "/opt/hiddify-manager/.venv313/lib/python3.13/site-packages/celery/worker/strategy.py", line 208, in task_message_handler
    hiddify-1          |     handle(req)
    hiddify-1          |   File "/opt/hiddify-manager/.venv313/lib/python3.13/site-packages/celery/worker/worker.py", line 226, in _process_task
    hiddify-1          |     req.execute_using_pool(self.pool)
    hiddify-1          |   File "/opt/hiddify-manager/.venv313/lib/python3.13/site-packages/celery/worker/request.py", line 767, in execute_using_pool
    hiddify-1          |     result = apply_async(
    hiddify-1          |   File "/opt/hiddify-manager/.venv313/lib/python3.13/site-packages/celery/concurrency/base.py", line 153, in apply_async
    hiddify-1          |     return self.on_apply(target, args, kwargs,
    hiddify-1          |   File "/opt/hiddify-manager/.venv313/lib/python3.13/site-packages/celery/concurrency/base.py", line 30, in apply_target
    hiddify-1          |     ret = target(*args, **kwargs)
    hiddify-1          |   File "/opt/hiddify-manager/.venv313/lib/python3.13/site-packages/celery/app/trace.py", line 694, in fast_trace_task
    hiddify-1          |     R, I, T, Rstr = tasks[task].__trace__(
    hiddify-1          |   File "/opt/hiddify-manager/.venv313/lib/python3.13/site-packages/celery/app/trace.py", line 479, in trace_task
    hiddify-1          |     R = retval = fun(*args, **kwargs)
    hiddify-1          |   File "/opt/hiddify-manager/.venv313/lib/python3.13/site-packages/celery/app/trace.py", line 779, in __protected_call__
    hiddify-1          |     return self.run(*args, **kwargs)
    hiddify-1          |   File "/opt/hiddify-manager/.venv313/lib/python3.13/site-packages/hiddifypanel/panel/usage.py", line 23, in update_local_usage
    hiddify-1          |     res = update_local_usage_not_lock()
    hiddify-1          |   File "/opt/hiddify-manager/.venv313/lib/python3.13/site-packages/hiddifypanel/panel/usage.py", line 39, in update_local_usage_not_lock
    hiddify-1          |     res = user_driver.get_users_usage(reset=True)
    hiddify-1          | > File "/opt/hiddify-manager/.venv313/lib/python3.13/site-packages/hiddifypanel/drivers/user_driver.py", line 26, in get_users_usage
    hiddify-1          |     all_usage = driver.get_all_usage()
    hiddify-1          |   File "/opt/hiddify-manager/.venv313/lib/python3.13/site-packages/hiddifypanel/drivers/singbox_api.py", line 43, in get_all_usage
    hiddify-1          |     usages = xray_client.stats_query('user', reset=True)
    hiddify-1          |   File "/opt/hiddify-manager/.venv313/lib/python3.13/site-packages/xtlsapi/singbox_api_services/stats/get_statsquery.py", line 10, in stats_query
    hiddify-1          |     return self.stats_stub.QueryStats(
    hiddify-1          |   File "/opt/hiddify-manager/.venv313/lib/python3.13/site-packages/grpc/_channel.py", line 1166, in __call__
    hiddify-1          |     return _end_unary_response_blocking(state, call, False, None)
    hiddify-1          |   File "/opt/hiddify-manager/.venv313/lib/python3.13/site-packages/grpc/_channel.py", line 996, in _end_unary_response_blocking
    hiddify-1          |     raise _InactiveRpcError(state)  # pytype: disable=not-instantiable
    hiddify-1          |
    hiddify-1          | grpc._channel._InactiveRpcError: <_InactiveRpcError of RPC that terminated with:
    hiddify-1          |    status = StatusCode.UNAVAILABLE
    hiddify-1          |    details = "failed to connect to all addresses; last error: UNKNOWN: ipv4:127.0.0.1:10086: Failed to connect to remote host: connect: Connection refused (111)"
    hiddify-1          |    debug_error_string = "UNKNOWN:Error received from peer  {grpc_message:"failed to connect to all addresses; last error: UNKNOWN: ipv4:127.0.0.1:10086: Failed to connect to remote host: connect: Connection refused (111)", grpc_status:14}"
    hiddify-1          | >
    hiddify-1          | 2026-01-24 19:01:09.694 | INFO     | hiddifypanel.panel.usage:add_users_usage_new:113 - creating a new daily usage 2026-01-24 admin=1 child=0
    hiddify-1          | 2026-01-24 19:01:09.703 | WARNING  | hiddifypanel.models.config:hconfig:79 - str last_priodic_usage_check not found
    hiddify-1          | 2026-01-24 19:01:09.704 | DEBUG    | hiddifypanel.panel.usage:_reset_priodic_usage:66 - reseting user usage if needed
    hiddify-1          | [2026-01-24 19:01:09,715: INFO/MainProcess] Task hiddifypanel.panel.usage.update_local_usage[d123b409-9541-4c91-bf6a-e2b34417e15e] succeeded in 0.20844844000021112s: {'status': 'success', 'comments': [], 'date': '2026-01-24 19:01:09'}

    When rerunning the script:

    docker compose exec hiddify bash
    cd /opt/hiddify-manager
    bash install.sh reinstall

    It does not complete, stopping at 2% (as already described here and etc...) with multiple errors.

    Additional details:

    • OS: Ubuntu 24.04 LTS x86_64, clean installation
    • Docker version 29.1.5, build 0e6fee6
    • Docker Compose version v5.0.2
  2. RB-PRO commented on Jul 10, 2026

    @RB-PRO

    send docker compose config pls

  3. miladmeidanshahi commented on Sep 27, 2026

    @miladmeidanshahi

    installation via docker has error please fix

Sign up for free to join this conversation on GitHub. Already have an account? Sign in to comment

Metadata

Metadata

Assignees

No one assigned

    Labels

    No labels
    No labels

    Type

    No type

    Projects

    No projects

      Milestone

      No milestone

      Relationships

      None yet

      Development

      No branches or pull requests

      Issue actions